
/* **************************************************************************
	Name of file: 	BRFSS prep.do
	
	Author: 		Emily Lawler  - emily.lawler@uga.edu
										
	Project: 		Middle School Vaccination
	
	Introduction:  This do-file cleans and standardizes raw BRFSS data files and produces 1 file with
		all years of BRFSS merged together.
				
				
	Last Edited:   06/2/2017 9:30 AM
	
	Files Used: BRFSS XPT files for 2012-2016
					
	Files Created: brfss_clean.dta
	NOTES:   
	1) 
	*************************************************************************** */
	
	capture clear
	capture log close 
	capture clear matrix
	set more off 
	estimates clear
	
* +++++++++++++++++++++++++++++++++++
global data     "$root/Data"
global NISdata  "$root/Data/NIS Teen"
global data2 	"$root/Data/Background"
global output   "$root/Output"
global tables   "$root/Output/Tables"
global figures  "$root/Output/Figures"
global dofiles  "$root/Do files"
global dofiles2 "$root/Do files/Background"
global logs 	"$root/Logs"
* +++++++++++++++++++++++++++++++++++

**************************************************

use "$data\brfss_2012_2016.dta", clear

label define tet 1 "Yes, received Tdap" 2 "Yes, recevied tetanus shot, but not Tdap" 3 "Yes, received tetanus shot but not sure what type" 4 "No, did not receive any tetanus since 2005" 7 "Don't know" 9 "Refused"
label values tetanus tet 

replace tetanus = 4 if tnsarcv==2 //havent received tetanus shot in last 10 years
replace tetanus = 4 if tnsarcnt==2  //havent received tetanus shot since 2005
replace tetanus = 1 if tnsasht1==1
replace tetanus = 2 if tnsasht1==2
replace tetanus = 3 if tnsasht1==7
replace tetanus = . if tnsarcnt==7|tnsarcnt==9

gen racecat4 = .
	replace racecat4 = 1 if _hispanc==2 & _mrace1==1 //non-hispanic, white
	replace racecat4 = 2 if _hispanc==2 & _mrace1==2	//non-hispanic, black
	replace racecat4 = 3 if _hispanc==2 & _mrace1>=3 & _mrace1<=77 //non-hispanic, other
	replace racecat4 = 4 if _hispanc==1 //hispanic
	
	replace racecat4 = 1 if hispanc2==2 & _mrace==1 //non-hispanic, white
	replace racecat4 = 2 if hispanc2==2 & _mrace==2	//non-hispanic, black
	replace racecat4 = 3 if hispanc2==2 & _mrace>=3 & _mrace<=77 //non-hispanic, other
	replace racecat4 = 4 if hispanc2==1 //hispanic

replace _age80=age if _age80==.
	replace _age80= 80 if age>80 & age!=.
	
gen agecat = .
	replace agecat = 1 if _age80>=18 & _age80<=24
	replace agecat = 2 if _age80>=25 & _age80<=34
	replace agecat = 3 if _age80>=35 & _age80<=44
	replace agecat = 4 if _age80>=45 & _age80<=54
	replace agecat = 5 if _age80>=55 & _age80<=64
	replace agecat = 6 if _age80>=65 & _age80!=.
	
recode sex (1=0) (2=1) (9=.), gen(female)

gen married = marital==1

recode educa (1 2 3=1) (4=2) (5=3) (6=4) (9=.), gen(educ4cat)
	
gen anychild = .
	replace anychild = 0 if children==88
	replace anychild = 1 if children>=1 & children<88
	
gen tdap2005 = .
	replace tdap2005 = 1 if tetanus==1
	replace tdap2005 = 0 if tetanus>=2 & tetanus<=4

gen tdap2005b = .
	replace tdap2005b = 1 if tetanus==1|tetanus==3
	replace tdap2005b = 0 if tetanus==2 |tetanus==4

gen td2005 = .
	replace td2005 = 1 if tetanus>=1 & tetanus<=3
	replace td2005 = 0 if tetanus==4

//merge in treatment vars and demographic controls

destring iyear imonth, replace

save "$data\brfss_clean.dta", replace
