	

/* **************************************************************************
	Name of file:  MSmandate_tdapvacc_otherages.do
	
	Author: 		Emily Lawler  - emily.lawler@uga.edu
										
	Project: 		Middle School Vaccination
	
	Introduction: 
				
				
	Last Edited:   10/16/2017 9:30 AM
	
	Files Used: 
					
	Files Created: 
								
	NOTES:   
	1) 
	*************************************************************************** */
	
	capture clear
	capture log close 
	capture clear matrix
	set more off 
	estimates clear
	

* +++++++++++++++++++++++++++++++++++
	* Secondary Globals - Dont change this! - 

global data     "$root/Data"
global NISdata  "$root/Data/NIS Teen"
global data2 	"$root/Data/Background"
global output   "$root\Output"
global tables   "$root/Output/Tables"
global figures  "$root/Output/Figures"
global dofiles  "$root/Do files"
global dofiles2 "$root/Do files/Background"
global logs 	"$root/Logs"
* +++++++++++++++++++++++++++++++++++

	foreach j of numlist 9 15 17{
	use  "$data\morbid_analysisfile.dta", clear
	
	//lagged versions of MCV vars
	gen MCV_boost = 0
	replace MCV_boost = 1 if m_MCVboost>=1 & m_MCVboost!=.

	gen MCVed_PS = 0
	replace MCVed_PS = 1 if m_MCVed_PS>=1 & m_MCVed_PS!=.

	gen MCVed = 0
	replace MCVed = 1 if m_MCVed>=1 & m_MCVed!=.

	gen MCV_waiver = 0
	replace MCV_waiver = 1 if m_MCV_PS>=1 & MCV_waiver_any==1

	gen MCV_PSmandate = 0
	replace MCV_PSmandate = 1 if m_MCV_PS>=1 & MCV_PSmandate_any==1
	
	keep fips year exemp_pb imminsure wc_insure HPVinsure HPVed_parent HPVed_stud /*
	*/ HPVaware hepB_Kmandate hepB_MSmandate hepA_CCmandate hepA_Kmandate /*
	*/ hepA_MSmandate hib_mandate varic_CC_Kmandate varic_MSmandate varic_2mandate /* 
	*/ pcv_mandate flu_CCmandate rota_mandate mumps_mandate meas_2mandate /*
	*/ menin_Bmandate Tdap_mandate TDcont_mandate MCV_mandate HPV_mandate /*
	*/ styr_perblack styr_perhispan styr_perother_eth styr_perfemale styr_perlt21 /*
	*/ styr_per21_64 styr_pergt64 styr_HSrate styr_uni2rate styr_uni4rate /*
	*/ styr_povrate unemp_rate mdcd_upperlmt pert_rate menin_rate MCV_boost /*
	*/ MCVed_PS MCVed MCV_waiver MCV_PSmandate pert_rate_lag menin_rate_lag tdap_allMSgrades 
	
rename year year`j'

tempfile vaccpolicy_st_yr`j'
save `vaccpolicy_st_yr`j''

*****************************************************************	

use "$data\NISteen08_15.dta", clear

	
	replace provwt= provwt_d if provwt==.
	replace rddwt=rddwt_d if rddwt==.
	
	gen TDcont7_9yrs =0 
	gen TDcont14_17yrs =0
	gen TDcont14_15yrs =0
	gen TDcont15_17yrs =0
	gen TDcont16_17yrs =0
	forvalues i=1/9{
	replace TDcont7_9yrs = 1 if TDP_AGE`i'>=7 & TDP_AGE`i'<=9
	replace TDcont14_17yrs = 1 if TDP_AGE`i'>=14 & TDP_AGE`i'<=17
	replace TDcont14_15yrs = 1 if TDP_AGE`i'>=14 & TDP_AGE`i'<=15
	replace TDcont15_17yrs = 1 if TDP_AGE`i'>=15 & TDP_AGE`i'<=17
	replace TDcont16_17yrs = 1 if TDP_AGE`i'>=16 & TDP_AGE`i'<=17
	}
		
	gen year`j' = year-age +`j'

* Merge in policy data

merge m:1 fips year`j' using `vaccpolicy_st_yr`j'', keep(master matched)
		ren _merge _merge1
 
//Analysis for receipt of a Tetanus containing vaccine between age 7-9, based on the CONTEMPORANEOUS implementation of a MS mandate


	gen trend = year`j'-2000
	gen trend_sq = trend*trend
	gen trend_cu = trend*trend*trend
	
	xi i.fips*trend i.fips*trend_sq i.fips*trend_cu 
	
	global linear "_IfipXtren_*"
	global quadratic "_IfipXtren_* _IfipXtrena*"
	global cubic "_IfipXtren_* _IfipXtrena* _IfipXtrenb*"
	
	global individ_controls "female child_lt18_* mom_ed_* married mom_agegrp_* ethcat_*"
	global VaccMandates "TDcont_mandate MCV_mandate HPV_mandate"
	global otherMandates "hepB_Kmandate hepB_MSmandate hepA_CCmandate hepA_Kmandate hepA_MSmandate hib_mandate varic_CC_Kmandate varic_MSmandate varic_2mandate pcv_mandate flu_CCmandate rota_mandate mumps_mandate meas_2mandate menin_Bmandate"
	global Vacc_controls "MCV_boost MCVed_PS MCVed MCV_waiver MCV_PSmandate exemp_pb wc_insure imminsure  HPVinsure HPVed_parent HPVed_stud HPVaware"	
	global styr "mdcd_upperlmt pert_rate_lag styr_perblack styr_perhispan styr_perother_eth styr_perfemale styr_perlt21 styr_per21_64 styr_HSrate styr_uni4rate styr_povrate unemp_rate"
	
	local lhs9 "TDcont7_9yrs"
	local lhs15 "TDcont14_15yrs"
	local lhs17 "TDcont16_17yrs"
		
	drop if year>=2014
	
	/*APPENDIX TABLE 6*/
	estimates clear
	eststo: reg `lhs`j''  $VaccMandates $Vacc_controls  $individ_controls $styr i.age i.fips i.year`j' if year`j'>=2005  [aw=provwt], vce(cluster fips)
	estadd ysumm
	estadd local linear ""
	estadd local samp ""
	
	tab year`j' if e(sample)==1
	bysort year`j': sum `lhs`j'' if e(sample)==1 [aw=provwt]
	
	eststo: reg `lhs`j''  $VaccMandates $Vacc_controls  $individ_controls $styr i.age i.fips i.year`j' $linear if year`j'>=2005   [aw=provwt], vce(cluster fips)
	estadd ysumm
	estadd local linear "X"
	estadd local samp ""
	
	eststo: reg `lhs`j''  $VaccMandates $Vacc_controls  $individ_controls $styr i.age i.fips i.year`j' if year`j'>=2005  & tdap_allMSgrades==0 [aw=provwt], vce(cluster fips)
	estadd ysumm
	estadd local linear ""
	estadd local samp "States w/o mandate for 13+ yo"
	
	tab year`j' if e(sample)==1
	bysort year`j': sum `lhs`j'' if e(sample)==1 [aw=provwt]
	
	eststo: reg `lhs`j''  $VaccMandates $Vacc_controls  $individ_controls $styr i.age i.fips i.year`j' $linear if year`j'>=2005 & tdap_allMSgrades==0  [aw=provwt], vce(cluster fips)
	estadd ysumm
	estadd local linear "X"
	estadd local samp "States w/o mandate for 13+ yo"
		
	
	esttab est* using "$output\vaccresults01152018.rtf", append keep(TDcont_*) /*
	*/ se label star(* 0.10 ** 0.05 *** 0.01) stats(N r2 ymean linear samp, label("N" "R-Squared" "Mean of Dependent" "linear trend" "Sample:")) title(Contemporaneous effects on other age groups (age =`j'), USING NIS-TEEN 2008-2015) /*
	*/ note("All columns are weighted, have age, state and birth cohort fixed effects. SE are clustered at the state level.")

	}

	
	
	
