
*Set this to the location of do & data files
	global root "D:\AEJ Replication Files"

	
* =========================================================================================

* +++++++++++++++++++++++++++++++++++
	* Secondary Globals - Dont change this! - 
cd "$root"
global data     "$root/Data"
global NISdata  "$root/Data/NIS Teen"
global data2 	"$root/Data/Background"
global output   "$root/Output"
global tables   "$root/Output/Tables"
global figures  "$root/Output/Figures"
global dofiles  "$root/Do files"
global logs 	"$root/Logs"

**************************************************************************************************
/*Merging together cleaned data files and creating analysis files*/

* Reading in policy variables, and coding them at the state-year level, as is relevant to 12 year olds
do "$dofiles\policy_prep1_year12.do"

do "$dofiles\policy_prep2_year12.do" //merges to (and cleans) NIS-Teen data

* Reading in policy variables, measured contemporaneously, and merging to surveillance data
	//this is where the confidential data on age-specific pertussiss is merged in ("$data\pert_2000_2015.dta")
do "$dofiles\morbidity_prep.do"

*Reading in NIS-child files and merging on contemporaneous policy measures
do "$dofiles\NIS_child_prep.do"

**********************************************************************************************************
/*Generate Figure 1*/

 use "$data\vacc_analysisfile.dta", clear

 //2. use dual-frame provider weights for 2011-2014 (note: cell phones added in 2011, & that is the only year with both a landline only & dual frame weight available)
	replace provwt= provwt_d if provwt==.
	replace rddwt=rddwt_d if rddwt==.
	
collapse (mean)  P_U13TDAP hpv1_13 P_U13MEN [aw=provwt], by(year12)

twoway (connected   P_U13TDAP year12, lpattern(solid) lcolor(gray) mcolor(blue) msymbol(o)) /*
		*/ (connected   hpv1_13 year12, lpattern(solid) lcolor(gray) mcolor(navy) msymbol(d)) /*
		*/ (connected   P_U13MEN year12, lpattern(solid) lcolor(gray) mcolor(dkgreen) msymbol(t)), /*
		*/ graphregion(fcolor(white)) ylabel(, nogrid angle(horizontal) ) /* 
		*/ scheme(s2mono) /*
		*/ yscale( nofextend ) xscale(nofextend) xlabel(2003(2)2013) /*
		*/ xtitle("Year") ytitle("Vaccination Rate") /*title("Rates of Adolescent Vaccination by Age 13")*/  note("Data from NIS-Teen") /*
		 */legend(order(1 "Tdap" 2 "HPV initiation" 3 "Menin."))
		 
graph export "$output\Figure1_vacc_trends_notitle.wmf", as(wmf) replace


********************************************************************************

/*Core analyses*/ 


* Vaccination outcomes by age 13, using NIS-Teen
do "$dofiles\vaccination_analysis.do"

* Morbidity analyses, using CDC surveillance data
do "$dofiles\morbidity_analysis.do" 

* Google Trends analyses
do "$dofiles\gtrends_analysis.do" 

* NIS-child analyses
do "$dofiles\NIS_child_analysis.do" 

* NIS-teen analyses, testing for vaccination spillovers to other age groups
	*APPENDIX TABLE 6
do "$dofiles\MSmandate_tdapvacc_otherages.do" 


*APPENDIX TABLE 3: Testing for non-linear effects of mandate on morbidity based on on prior disease incidence
do "$dofiles\morbid_baselinediseaseinteraction.do"
***************************************************************************************************************
/* Additional analyses mentioned but not presented in either main text or appendix*/

*Testing for spillover effects to Tdap vaccination of adults
do "$dofiles\BRFSS prep.do" //cleans and merges together 2012-2016 BRFSS waves

do "$dofiles\brfss_analysis.do" 




