

/* **************************************************************************
	Name of file: 	NIS_child_analysis.do
	
	Author: 		Emily Lawler  - emily.lawler@uga.edu
										
	Project: 		Middle School Vaccination
	
	Introduction: 
				
				
	Last Edited:   01/15/2018 9:30 AM
	
	Files Used: 
					
	Files Created: 
								
	NOTES:   
	1) 
	*************************************************************************** */
	
	capture clear
	capture log close 
	capture clear matrix
	set more off 
	estimates clear
	
* +++++++++++++++++++++++++++++++++++
	* Secondary Globals - Dont change this! - 
global data     "$root/Data"
global NISdata  "$root/Data/NIS Teen"
global data2 	"$root/Data/Background"
global output   "$root\Output"
global tables   "$root/Output/Tables"
global figures  "$root/Output/Figures"
global dofiles  "$root/Do files"
global dofiles2 "$root/Do files/Background"
global logs 	"$root/Logs"
* +++++++++++++++++++++++++++++++++++


 use "$data\nis_analysisfile.dta", clear

	gen trend = year-2003
	gen trend_sq = trend*trend
	gen trend_cu = trend*trend*trend
	
	xi i.fips*trend i.fips*trend_sq i.fips*trend_cu 
	
	global linear "_IfipXtren_*"
	global quadratic "_IfipXtren_* _IfipXtrena*"
	global cubic "_IfipXtren_* _IfipXtrena* _IfipXtrenb*"
	
	global individ_controls "agegrp_* WIC_ever child_lt18_* frstbrn mom_ed_* married mom_agegrp_* ethcat_* female"
	
	global VaccMandates "TDcont_mandate MCV_mandate HPV_mandate hepB_Kmandate hepB_MSmandate hepA_CCmandate hepA_Kmandate hepA_MSmandate hib_mandate varic_CC_Kmandate varic_MSmandate varic_2mandate pcv_mandate flu_CCmandate rota_mandate mumps_mandate meas_2mandate menin_Bmandate"
	global Vacc_controls "MCV_boost MCVed_PS MCVed MCV_waiver MCV_PSmandate exemp_pb wc_insure wc_insure_12yo imminsure imminsure_12yo HPVinsure HPVed_parent HPVed_stud HPVaware" //Also: HPVpharm, only to be used in analysis 2009 forward
	global styr "pert_rate_2lag menin_rate_2lag mdcd_upperlmt styr_perblack styr_perhispan styr_perother_eth styr_perfemale styr_perlt21 styr_per21_64 styr_HSrate styr_uni4rate styr_povrate unemp_rate"

	
	global LHS "P_UTDTP4"
	label var P_UTDHEP "UTD HepB"
	label var P_UTDHIB "UTD Hib"
	label var P_UTDMMX "UTD MMR"
	label var P_UTDPC3 "UTD PCV" //pneumococcal
	label var P_UTDPOL "UTD Polio"
	label var P_UTDTP3 "UTD DTP3"
	label var P_UTDTP4 "UTD DTP4"
	

	*****************************************************
	sum $individ_controls year [aw=wgt_prov]
	sum $VaccMandates [aw=wgt_prov]
	sum $Vacc_controls [aw=wgt_prov]
	sum $styr year [aw=wgt_prov]
	
	
	quietly{
	eststo: reg P_UTDTP4  $VaccMandates  $Vacc_controls  $individ_controls $styr  i.fips i.year [aw=wgt_prov], vce(cluster fips)
	}
	tab year if e(sample)==1
	sum P_UTDTP4 if e(sample)==1 & year==2003 [aw=wgt_prov]
	sum P_UTDTP4 if e(sample)==1 & year==2015 [aw=wgt_prov]
	
	quietly{
	eststo: reg P_UTDTP4  $VaccMandates  $Vacc_controls  $individ_controls $styr  i.fips i.year [aw=wgt_prov] if child_lt18_1==0, vce(cluster fips)
	}
	tab year if e(sample)==1
	sum P_UTDTP4 if e(sample)==1 & year==2003 [aw=wgt_prov]
	sum P_UTDTP4 if e(sample)==1 & year==2015 [aw=wgt_prov]
	
	quietly{
	eststo: reg P_UTDTP4  $VaccMandates  $Vacc_controls  $individ_controls $styr  i.fips i.year [aw=wgt_prov] if child_lt18_1==1, vce(cluster fips)
	}
	tab year if e(sample)==1
	sum P_UTDTP4 if e(sample)==1 & year==2003 [aw=wgt_prov]
	sum P_UTDTP4 if e(sample)==1 & year==2015 [aw=wgt_prov]
	
	/*APPENDIX TABLE 7*/
	* Standard DD specifications 
	foreach var of global LHS{
	quietly{
	estimates clear
	
	eststo: reg `var' $VaccMandates $Vacc_controls  $individ_controls $styr  i.fips i.year  $linear [aw=wgt_prov], vce(cluster fips)
	estadd ysumm
	estadd local linear "X"
	estadd local fam "All"
	
	eststo: reg `var' $VaccMandates $Vacc_controls  $individ_controls $styr  i.fips i.year  $linear [aw=wgt_prov] if child_lt18_1==0, vce(cluster fips)
	estadd ysumm
	estadd local linear "X"
	estadd local fam ">1 child in HH"
	
	eststo: reg `var' $VaccMandates $Vacc_controls  $individ_controls $styr  i.fips i.year  $linear [aw=wgt_prov] if child_lt18_1==1, vce(cluster fips)
	estadd ysumm
	estadd local linear "X"
	estadd local fam "1 child in HH"
	
	}
	esttab est* using "$output\NISvaccresults_01152018.rtf", append keep(TDcont_mandate) /*
	*/ se label star(* 0.10 ** 0.05 *** 0.01) stats(fam linear N r2 ymean, label("Sample:" "linear trend" "Observations" "R-Squared" "Mean of Dependent")) title(Effects of mandates on receipt of `var') /*
	*/ note("All columns are weighted, have age, state and birth cohort fixed effects. SE are clustered at the state level.")
	}
	
