/* **************************************************************************
	Name of file: 	NIS_child_prep.do
	
	Author: 		Emily Lawler  - emily.lawler@uga.edu
										
	Project: 		Middle School Vaccination
	
	Introduction: 
				
				
	Last Edited:   08/29/2016 9:30 AM
	
	Files Used: 
					
	Files Created: nis_analysisfile.dta
								
	NOTES:   
	1) 
	*************************************************************************** */
	
	capture clear
	capture log close 
	capture clear matrix
	set more off 
	estimates clear
	

* +++++++++++++++++++++++++++++++++++

global data     "$root/Data"
global NISdata  "$root/Data/NIS Teen"
global NIS2		"$root/Data/NIS"
global data2 	"$root/Data/Background"
global output   "$root/Output"
global tables   "$root/Output/Tables"
global figures  "$root/Output/Figures"
global dofiles  "$root/Do files"
global dofiles2 "$root/Do files/Background"
global logs 	"$root/Logs"
* +++++++++++++++++++++++++++++++++++

	****************************************************
	use "$data\nis03_15_raw.dta", clear
	
	gen agegrp_1 = (agegrp==1)
	label var agegrp_1 "1= 19-23 mos"
	gen agegrp_2 = (agegrp==2)
	label var agegrp_2 "1= 24-29 mos"
	gen agegrp_3 = (agegrp==3)
	label var agegrp_3 "1= 30-35 mos"
	
	recode WIC_ever (1=1) (3 2 =0) (77 99 6 7 = .)
	label var WIC_ever "1= ever received WIC, 0=never"
	
	recode WIC_current (1=1) (2 = 0) (77 99 6 7 = . )
	label var WIC_current "1= currently receiving WIC, 0=not"
	
	gen child_lt18_1 = (child_lt18==1)
	label var child_lt18_1 "1= Only 1 child lt 18 in HH"
	gen child_lt18_2 = (child_lt18==2)
	label var child_lt18_2 "1= 2-3 children lt 18 in HH"
	gen child_lt18_3 = (child_lt18==3)
	label var child_lt18_3 "1= 4+ children lt 18 in HH"
	
	gen mom_ed_1 = (mom_ed==1)
	label var mom_ed_1 "Less than HS"
	gen mom_ed_2 = (mom_ed==2)
	label var mom_ed_2 "HS (12yrs)"
	gen mom_ed_3 = (mom_ed==3)
	label var mom_ed_3 "Some college (>12 yrs)"
	gen mom_ed_4 = (mom_ed==4)
	label var mom_ed_4 "college grad"
	
	recode frstbrn (1=0) (2=1)
	label var frstbrn "1= Is the first born child"
	
	//inc_povratio consistent across years
	//inc_povind is not, replace with a dummy for inc_povratio being above/below 1
	drop inc_povind
	gen inc_povind = .
	replace inc_povind =1 if inc_povratio<=1 & inc_povratio!=.
	replace inc_povind =0 if inc_povratio>1 & inc_povratio!=.
	
	//inc_cat is coded one way for 2003 & 2004, then different categories used for 2005-2013
	/* For 2003-2004:
		3: 0 - $ 7,500
		4: $ 7,501 - $10,000
		 5: $10,001 - $12,500
		 6: $12,501 - $15,000
		  7: $15,001 - $17,500
		  8: $17,501 - $20,000
		  9: $20,001 - $25,000
		 10: $25,001 - $30,000
		  11: $30,001 - $35,000
		  12: $35,001 - $40,000
		 13: $40,001 - $45,000
		  14: $45,001 - $50,000
		 15: $50,001 +
		  96 DON'T KNOW
		  97 REFUSED
		
		for 2005-2013:
			$0 - $7500 3 
		$7501 - $10000 4 
		$10001 - $17500 5 
		$17501 - $20000 6 
		$20001 - $25000 7 
		$25001 - $30000 8 
		$30001 - $35000 9 
		$35001 - $40000 10 
		$40001 - $50000 11 
		$50001 - $60000 12 
		$60001 - $75000 13 
		$75001+ 14 
		DON'T KNOW 77 
		REFUSED 99
		*/
	gen inc_cat_clean=.
	replace inc_cat_clean = 1 if inc_cat==3|inc_cat==4 //$0-10,000
	replace inc_cat_clean = 2 if (inc_cat==5|inc_cat==6|inc_cat==7|inc_cat==8) & year<=2004 //$10,001-20,000
	replace inc_cat_clean = 2 if (inc_cat==5|inc_cat==6) & year>=2005
	replace inc_cat_clean = 3 if (inc_cat==9|inc_cat==10) & year<=2004 //$20,001-30,000
	replace inc_cat_clean = 3 if (inc_cat==7|inc_cat==8) & year>=2005
	replace inc_cat_clean = 4 if (inc_cat==11|inc_cat==12) & year<=2004 //$30,001-40,000
	replace inc_cat_clean = 4 if (inc_cat==9|inc_cat==10) & year>=2005
	replace inc_cat_clean = 5 if (inc_cat==13|inc_cat==14) & year<=2004 //$40,001-50,000
	replace inc_cat_clean = 5 if inc_cat==11 & year>=2005
	replace inc_cat_clean = 6 if inc_cat==15 & year<=2004 //$50,001+
	replace inc_cat_clean = 6 if (inc_cat==12|inc_cat==13|inc_cat==14) & year>=2005
	
	drop inc_cat
	rename inc_cat_clean inc_cat
	
	label var inc_cat "Cleaned family income categories, ECL"
	label def inc_cat 1 "$0-10,000" 2 "$10,001-20,000" 3 "$20,001-30,000" 4 "$30,001-40,000" 5 "$40,001-50,000" 6 "$50,001+"
	label value inc_cat inc_cat
	tab inc_cat, gen (inc_cat_)
	
	recode inc_cat (1=1) (2=2) (3=3) (4 5=4) (6=5), gen(inc_cat2)
	label def inc_cat2 1 "$0-10,000" 2 "$10,001-20,000" 3 "$20,001-30,000" 4 "$30,001-50,000" 5 "$50,001+"
	label value inc_cat2 inc_cat2
	tab inc_cat2, gen(inc_cat2_)
	
	gen married = 0
	replace married = 1 if marital==3 & year<=2008
	replace married = 1 if marital ==1 & year>=2009
	drop marital
	
	gen mom_agegrp_1 = (mom_agegrp==1)
	label var mom_agegrp_1 "1= Mom <=19yo"
	gen mom_agegrp_2 = (mom_agegrp==2)
	label var mom_agegrp_2 "1= Mom 20-29yo"
	gen mom_agegrp_3 = (mom_agegrp==3)
	label var mom_agegrp_3 "1= Mom 30+yo"
	
	gen ethcat_1 = (race_ethcat==1)
	label var ethcat_1 "1=Hispanic"
	gen ethcat_2 = (race_ethcat==2)
	label var ethcat_2 "1=non-Hispanic, white"
	gen ethcat_3 = (race_ethcat==3)
	label var ethcat_3 "1=non-Hispanic, black"
	gen ethcat_4 = (race_ethcat==4)
	label var ethcat_4 "1=non-Hispanic other + multiple race"
	
	recode sex (1=0) (2=1), gen(female)
	label var female "1=child is a female, 0=male"
	
	rename P_U12VRC p_varic_dum
	
	recode P_UTDFL1 (1=1) (2=0) (3=.), gen(utd_flu)
	gen flu_any = P_NUMFLU>=1
		replace flu_any = . if P_NUMFLU==.
	
	//recode of insurance variables
	recode INS_1 (1=1) (2=0) (77 99=.), gen(ins_empl)
	label var ins_empl "1= covered by employer/union insurance"
	
	recode INS_2 (1=1) (2=0) (77 99=.), gen(ins_medcd)
	label var ins_medcd "1= covered by medicaid"
	
	recode INS_3 (1=1) (2=0) (77 99=.), gen(ins_schip)
	label var ins_schip "1 = covered by schip"
	
	recode INS_3A (1=1) (2=0) (77 99=.), gen(ins_medcd_schip)
	label var ins_medcd_schip "1= covered by medicaid or schip"
	
	recode INS_4_5 (1=1) (2=0) (77 99=.), gen(ins_otherpub)
	label var ins_otherpub "1= covered by IHS, military, tricare, CHAMPUS, or CHAMP-VA"
	
	recode INS_6 (1=1) (2=0) (77 99=.), gen(ins_other)
	label var ins_other "1= covered by other health insurance"
	
	recode INS_11 (1=1) (2=0) (77 99=.), gen(unins_ever)
	label var unins_ever "1= ever uninsured"
	

	
	rename state fips
	//drop virgin islands and guam (not available for all years & don't have policy info)
	drop if fips==66|fips==78
	
	save "$data\nis03_15.dta", replace
	************************************************************************
	use "$data\cdc_diseases_surv_1996_2015.dta", clear
	gen pert_rate_2lag = (pert/total_pop)*100
	gen menin_rate_2lag = (menin/total_pop)*100
	replace year =year+2
	tempfile cdc_2lag
	save `cdc_2lag'
	clear
	
	use "$data2\st_yr_cps.dta", clear
	replace year =year+1
	tempfile cps_lag
	save `cps_lag'
	clear
	
	use "$data2\BLS_st_yr.dta", clear
	replace year =year+1
	tempfile bls_lag
	save `bls_lag'
	clear
	
	
	use "$data\nis03_15.dta", clear
	
	merge m:1 fips year using "$data\vaccpolicy_st_yr.dta", keep(master matched)
		ren _merge _merge1
	merge m:1 fips year using `cps_lag', keep(master matched)
		ren _merge _merge2
			drop pop_*
	merge m:1 fips year using `bls_lag', keep(master matched)
		ren _merge _merge3
	merge m:1 fips year using "$data\medicaid_thresholds_2000_2015.dta", keep(master matched) keepusing(mdcd_upperlmt)
		ren _merge _merge4
	merge m:1 fips year using `cdc_2lag', keep(master matched) keepusing(pert_rate_2lag menin_rate_2lag)
		ren _merge _merge5
	drop _merge*
		
	//lagged versions of MCV vars
	gen MCV_boost = 0
	replace MCV_boost = 1 if m_MCVboost>=1 & m_MCVboost!=.

	gen MCVed_PS = 0
	replace MCVed_PS = 1 if m_MCVed_PS>=1 & m_MCVed_PS!=.

	gen MCVed = 0
	replace MCVed = 1 if m_MCVed>=1 & m_MCVed!=.

	gen MCV_waiver = 0
	replace MCV_waiver = 1 if m_MCV_PS>=1 & MCV_waiver_any==1

	gen MCV_PSmandate = 0
	replace MCV_PSmandate = 1 if m_MCV_PS>=1 & MCV_PSmandate_any==1
		
	//for now, use dual weights for 2012 and 2013, and land-line weights for all other years
	replace wgt_prov = wgt_prov_d if year>=2012
	
	gen wgt_prov_2 = wgt_prov
	replace wgt_prov_2 = wgt_prov_d if year==2011
	label var wgt_prov_2 "Uses dual weights for 2011-2015"
	
	//create a dummy for if an individual has any hepA shots
	//as reported by provider
	gen p_hepA_dum = p_hepA_num
	replace p_hepA_dum=1 if p_hepA_num==2 |p_hepA_num==3| p_hepA_num==4
	label var p_hepA_dum "dummy for if an individual has any hepA shots"
	
	gen p_hepA_dum2 = 0
	replace p_hepA_dum2=1 if p_hepA_num==2 |p_hepA_num==3| p_hepA_num==4 
	label var p_hepA_dum "dummy for if an individual has had TWO+ hepA shots"
	label var p_hepA_dum "Hep A Vacc"
	
	drop if inc_cat==.
	
	save "$data\nis_analysisfile.dta", replace

	
	
