/* **************************************************************************
	Name of file: 	gtrends_analysis.do
	
	Author: 		Emily Lawler  - emily.lawler@uga.edu
										
	Project: 		Middle School Vaccination
	
	Introduction: 
				
				
	Last Edited:   08/22/2016 9:30 AM
	
	Files Used: 
					
	Files Created: 
								
	NOTES:   
	1) Uses contemporaneous policy information from morbidity analyses, and merges that on to 
	the cleaned BRFSS files
	2) Estimates effects on pr(tdap shot since 2005), includes code to bootstrap standard errors
	to adust for small number of states in sample
	*************************************************************************** */
	
	capture clear
	capture log close 
	capture clear matrix
	set more off 
	estimates clear
	

* +++++++++++++++++++++++++++++++++++
global data     "$root/Data"
global NISdata  "$root/Data/NIS Teen"
global data2 	"$root/Data/Background"
global output   "$root/Output"
global tables   "$root/Output/Tables"
global figures  "$root/Output/Figures"
global dofiles  "$root/Do files"
global dofiles2 "$root/Do files/Background"
global logs 	"$root/Logs"
* +++++++++++++++++++++++++++++++++++

use "$data2\st_yr_cps.dta", clear
keep if year==2016
foreach var of varlist styr_perblack-styr_povrate{
rename `var' `var'2016
}

tempfile cps2016
save `cps2016'

use "$data2\BLS_st_yr.dta", clear
keep if year==2016

rename pop pop2016
rename unemp_rate unemp_rate2016
tempfile bls2016
save `bls2016'

*************************************************************
use  "$data\morbid_analysisfile.dta", clear
	
	//lagged versions of MCV vars
	gen MCV_boost = 0
	replace MCV_boost = 1 if m_MCVboost>=1 & m_MCVboost!=.

	gen MCVed_PS = 0
	replace MCVed_PS = 1 if m_MCVed_PS>=1 & m_MCVed_PS!=.

	gen MCVed = 0
	replace MCVed = 1 if m_MCVed>=1 & m_MCVed!=.

	gen MCV_waiver = 0
	replace MCV_waiver = 1 if m_MCV_PS>=1 & MCV_waiver_any==1

	gen MCV_PSmandate = 0
	replace MCV_PSmandate = 1 if m_MCV_PS>=1 & MCV_PSmandate_any==1
	
	keep fips year exemp_pb imminsure wc_insure HPVinsure HPVed_parent HPVed_stud /*
	*/ HPVaware hepB_Kmandate hepB_MSmandate hepA_CCmandate hepA_Kmandate /*
	*/ hepA_MSmandate hib_mandate varic_CC_Kmandate varic_MSmandate varic_2mandate /* 
	*/ pcv_mandate flu_CCmandate rota_mandate mumps_mandate meas_2mandate /*
	*/ menin_Bmandate Tdap_mandate TDcont_mandate MCV_mandate HPV_mandate /*
	*/ styr_perblack styr_perhispan styr_perother_eth styr_perfemale styr_perlt21 /*
	*/ styr_per21_64 styr_pergt64 styr_HSrate styr_uni2rate styr_uni4rate /*
	*/ styr_povrate unemp_rate mdcd_upperlmt pert_rate menin_rate MCV_boost /*
	*/ MCVed_PS MCVed MCV_waiver MCV_PSmandate pert_rate_lag menin_rate_lag tdap_allMSgrades 

//assigning 2015 policy info to 2016 [*verified that there are no changes*]
foreach var of varlist tdap_allMSgrades-HPV_mandate mdcd_upperlmt {
replace `var' = `var'[_n-1] if year==2016 & year[_n-1]==2015 & fips==fips[_n-1]
}

merge 1:1 fips year using `cps2016', nogen
foreach var of varlist styr_perblack-styr_povrate{
replace `var'= `var'2016 if year==2016 & `var'==.
drop `var'2016
}

merge 1:1 fips year using `bls2016', nogen


replace unemp_rate = unemp_rate2016 if year==2016
drop pop2016 unemp_rate2016

tempfile vaccpolicy_st_yr
save `vaccpolicy_st_yr'

********************************************


use "$data\brfss_clean.dta", clear
	rename _state fips
	
	drop if fips==66|fips==72|fips==78	
	
* Merge in policy data

merge m:1 fips year using `vaccpolicy_st_yr', keep(master matched)
		ren _merge _merge1
 
gen date = year if imonth<=6 & iyear==year
	replace date = year +.5 if imonth>6 & iyear==year
	replace date = year +.5 if year!=iyear & imonth<6
	
egen halfyear =group(date)

	tab educ4cat, gen(educ_)
	tab racecat, gen(racecat_)
	tab agecat, gen(agecat_)
	tab year, gen(year_)
	tab fips, gen(fips_)
	tab halfyear, gen(halfyear_)
	
	gen age_sq =_age80*_age80
	
	gen trend = date-2011
	gen trend_sq = trend*trend
	gen trend_cu = trend*trend*trend
	
	xi i.fips*trend i.fips*trend_sq i.fips*trend_cu 
	
	global linear "_IfipXtren_*"
	global quadratic "_IfipXtren_* _IfipXtrena*"
	global cubic "_IfipXtren_* _IfipXtrena* _IfipXtrenb*"
	
	global individ_controls "female married i.educ4cat i.racecat4 i.agecat anychild"
	global individ_controls2 "female married i.educ4cat i.racecat4 _age80 age_sq anychild"
	global VaccMandates "MCV_mandate HPV_mandate"
	global otherMandates "hepB_Kmandate hepB_MSmandate hepA_CCmandate hepA_Kmandate hepA_MSmandate hib_mandate varic_CC_Kmandate varic_MSmandate varic_2mandate pcv_mandate flu_CCmandate rota_mandate mumps_mandate meas_2mandate menin_Bmandate"
	global Vacc_controls "MCV_boost MCVed_PS MCVed MCV_waiver MCV_PSmandate exemp_pb wc_insure imminsure  HPVinsure HPVed_parent HPVed_stud HPVaware"	
	global styr "mdcd_upperlmt pert_rate_lag styr_perblack styr_perhispan styr_perother_eth styr_perfemale styr_perlt21 styr_per21_64 styr_HSrate styr_uni4rate styr_povrate unemp_rate"
	
	
	* Add in month of implementation information, since have survey month in BRFSS
	gen TDcont_mandateB = TDcont_mandate
		replace TDcont_mandateB = 1 if fips==13 & iyear==2014 & imonth>=8
		replace TDcont_mandateB = 1 if fips==13 & iyear==2015
		replace TDcont_mandateB = 1 if fips==45 & iyear==2013 & imonth>=8

	
	local lhs1 "tdap2005" //receipt of tdap vaccine
	local lhs2 "tdap2005b" //reciept of tdap or td, with pertussis content unknown (excludes those that know did not receive tdap)
	local lhs3 "td2005" //receipt of any td-containing
	
	estimates clear
	forvalues j=1/1{
	
	
	eststo: reg `lhs`j''  TDcont_mandateB $VaccMandates $otherMandates $Vacc_controls  $individ_controls2 $styr i.fips i.iyear i.imonth [aw=_llcpwt], vce(cluster fips)
	estadd ysumm
	estadd local linear ""
	estadd local samp "18+"
		
	}
	
	forvalues j=1/1{

	eststo: reg `lhs`j''  TDcont_mandateB $VaccMandates $otherMandates $Vacc_controls  $individ_controls2 $styr i.fips i.iyear i.imonth if agecat>=1 & agecat<=5  [aw=_llcpwt], vce(cluster fips)
	estadd ysumm
	estadd local linear ""
	estadd local samp "18-64"

	
}
	local lhs1 "tdap2005"
	local lhs2 "tdap2005b"
	local lhs3 "td2005"
	
	local lbl1 "age 18-24"
	local lbl2 "age 25-34"
	local lbl3 "age 35-44"
	local lbl4 "age 45-54"
	local lbl5 "age 55-64"
	local lbl6 "age 65+"
	
	//by age group 
	foreach i of numlist 1/6{
	forvalues j=1/1{
	
	
	eststo: reg `lhs`j''  TDcont_mandateB $VaccMandates $otherMandates $Vacc_controls  $individ_controls2 $styr i.fips i.iyear i.imonth if agecat==`i'  [aw=_llcpwt], vce(cluster fips)
	estadd ysumm
	estadd local linear ""
	estadd local samp "`lbl`i''"
		
		}
	}
	
		

	esttab est* using "$output\brfssresults01152018.rtf", append keep(TDcont_*) /*
	*/ se label star(* 0.10 ** 0.05 *** 0.01) stats(N r2 ymean linear samp, label("N" "R-Squared" "Mean of Dependent" "linear trend" "Sample:")) title(Contemporaneous effects on adults `lbl`i'', USING BRFSS 2012-2016) /*
	*/ note("All columns are weighted, have state and month and year fixed effects. Age enters as age and age_sq SE are clustered at the state level.")
	
	
		**BOOTSTRAPPED***

		/*
tab iyear, gen(iyear_)
tab imonth, gen(imonth_)
	
	estimates clear
	eststo: cgmwildboot tdap2005  TDcont_mandateB $VaccMandates $otherMandates $Vacc_controls  $styr female married  anychild educ_* racecat_* _age80 age_sq iyear_* imonth_* fips_*   [aw=_llcpwt], cluster(fips) bootcluster(fips)
	estadd ysumm
	estadd local linear ""
	estadd local samp "18+"
	
	eststo: cgmwildboot tdap2005  TDcont_mandateB $VaccMandates $otherMandates $Vacc_controls  $styr female married  anychild educ_* racecat_* _age80 age_sq iyear_* imonth_* fips_*  if agecat>=1 & agecat<=5  [aw=_llcpwt], cluster(fips) bootcluster(fips)
	estadd ysumm
	estadd local linear ""
	estadd local samp "18-64"
	
	esttab est* using "$output\brfssresults01152018B.rtf", append keep(TDcont_*) /*
	*/ se label star(* 0.10 ** 0.05 *** 0.01) stats(N r2 ymean linear samp, label("N" "R-Squared" "Mean of Dependent" "linear trend" "Sample:")) title(Contemporaneous effects on adults, USING BRFSS 2012-2016) /*
	*/ note("All columns are weighted, have state and _age80 age_sq iyear_* imonth_*. SE are clustered at the state level.")

	
	local lbl1 "age 18-24"
	local lbl2 "age 25-34"
	local lbl3 "age 35-44"
	local lbl4 "age 45-54"
	local lbl5 "age 55-64"
	local lbl6 "age 65+"
	
		estimates clear
	foreach i of numlist 1/6{

		eststo: cgmwildboot tdap2005  TDcont_mandateB $VaccMandates $otherMandates $Vacc_controls  $styr female married  anychild educ_* racecat_* _age80 age_sq iyear_* imonth_* fips_*  if agecat==`i' [aw=_llcpwt], cluster(fips) bootcluster(fips)
	estadd ysumm
	estadd local linear ""
	estadd local samp "`lbl`i''"
	}

	esttab est* using "$output\brfssresults01152018B.rtf", append keep(TDcont_*) /*
	*/ se label star(* 0.10 ** 0.05 *** 0.01) stats(N r2 ymean linear samp, label("N" "R-Squared" "Mean of Dependent" "linear trend" "Sample:")) title(Contemporaneous effects on adults `lbl`i'', USING BRFSS 2012-2016) /*
	*/ note("All columns are weighted, have state and _age80 age_sq iyear_* imonth_*. SE are clustered at the state level.")
	

	
