
	/* **************************************************************************
	Name of file: 	gtrends_analysis.do
	
	Author: 		Emily Lawler  - emily.lawler@uga.edu
										
	Project: 		Middle School Vaccination
	
	Introduction: 
				
				
	Last Edited:   05/17/2018 9:30 AM
	
	Files Used: 
					
	Files Created: 
								
	NOTES:   
	1) 
	*************************************************************************** */
	
	capture clear
	capture log close 
	capture clear matrix
	set more off 
	estimates clear

* +++++++++++++++++++++++++++++++++++

global data     "$root/Data"
global NISdata  "$root/Data/NIS Teen"
global data2 	"$root/Data/Background"
global output   "$root/Output"
global tables   "$root/Output/Tables"
global figures  "$root/Output/Figures"
global dofiles  "$root/Do files"
global dofiles2 "$root/Do files/Background"
global logs 	"$root/Logs"
* +++++++++++++++++++++++++++++++++++

	***********************************************
	//Merge in policy info and controls//
	*************************************************

use "$data\gtrends.dta", clear

//merge 1:1 fips year month using "$data\google flu_month_analysisfile.dta", keep(master matched) nogen
merge m:1 fips year using "$data\vaccpolicy_st_yr.dta", keep(master matched)
	ren _merge _merge0
merge m:1 fips year using "$data\pert_2000_2015.dta", keep(master matched)
	ren _merge _merge1
merge m:1 fips year using "$data\cdc_diseases_surv_1996_2015.dta", keep(master matched) keepusing(menin)	
	ren _merge _merge3
merge m:1 fips year using "$data2\st_yr_cps.dta", keep(master matched)
	ren _merge _merge4
		drop pop_*
merge m:1 fips year using "$data2\BLS_st_yr.dta", keep(master matched)
	ren _merge _merge5
	drop pop
merge m:1 fips year using "$data\medicaid_thresholds_2000_2015.dta", keep(master matched) keepusing(mdcd_upperlmt)
		ren _merge _merge6

drop _merge*
	
global agegrp "0_4 5_9 10_14 15_19 20_24 25_29 30_34 35_39 40_44 45_49 50_54 55_59 60_64 65plus"
	
gen total_pop = 0
	foreach age of global agegrp{
		replace total_pop = total_pop + pop`age'
	}


	
drop if year>2015
drop if year<2003

save "$data\gtrends_month_analysisfile.dta", replace

	***********************************************
	//ANALYSIS//
	*************************************************
	
 use "$data\gtrends_month_analysisfile.dta", clear

	gen trend = year-2005
	gen trend_sq = trend*trend
	gen trend_cu = trend*trend*trend
	
	xi i.fips*trend i.fips*trend_sq i.fips*trend_cu 
	
	global linear "_IfipXtren_*"
	global quadratic "_IfipXtren_* _IfipXtrena*"
	global cubic "_IfipXtren_* _IfipXtrena* _IfipXtrenb*"
	

	gen pert_rate = (pert_tot/total_pop)*100000
	gen menin_rate = (menin/total_pop)*100000
	
	
		//gen a lagged measure of annual state pertussis incidence
	sort state month year
	gen pert_lag =.
	replace pert_lag = pert_rate[_n-1] if fips==fips[_n-1] & month==month[_n-1] & year==year[_n-1]+1
	
	gen menin_lag =.
	replace menin_lag = menin_rate[_n-1] if fips==fips[_n-1] & month==month[_n-1] & year==year[_n-1]+1
	
	gen TDcont_month = .
	replace TDcont_month = tdap_month if Tdap_yr==TDcont_yr
	replace TDcont_month = 8 if TDcont_month==. & TDcont_yr!=.
	
	//undo the 1 year lag on mandates and other policies
	replace TDcont_mandate = 1 if year==TDcont_yr //& month>=TDcont_month
	replace MCV_mandate = 1 if year==MCV_yr //& month>=8
	replace HPV_mandate = 1 if year==HPV_yr //& month>=8
	
	replace HPVinsure =1 if year==HPVinsure_year 
	replace HPVed_parent =1 if year==HPVed_parent_yr & HPVed_parent_yr!=. 
	replace HPVed_stud =1 if year==HPVed_stud_yr & HPVed_stud_yr!=. 
	replace HPVaware =1 if year==HPVaware_yr & HPVaware_yr!=. 
	
	gen MCV_boost = 0
	replace MCV_boost = 1 if m_MCVboost>=0 & m_MCVboost!=.

	gen MCVed_PS = 0
	replace MCVed_PS = 1 if m_MCVed_PS>=0 & m_MCVed_PS!=.

	gen MCVed = 0
	replace MCVed = 1 if m_MCVed>=0 & m_MCVed!=.

	gen MCV_waiver = 0
	replace MCV_waiver = 1 if m_MCV_PS>=0 & MCV_waiver_any==1

	gen MCV_PSmandate = 0
	replace MCV_PSmandate = 1 if m_MCV_PS>=0 & MCV_PSmandate_any==1
	

	foreach var of global MS_vacc{
	global es_`var' " M_`var'_ltneg5 M_`var'_neg5 M_`var'_neg4 M_`var'_neg3 M_`var'_neg2 M_`var'_0 M_`var'_1 M_`var'_2 M_`var'_3 M_`var'_4 M_`var'_5 M_`var'_gt5"
	}
	
	//note: all of these mandates are lagged 1 year
	global VaccMandates "TDcont_mandate MCV_mandate HPV_mandate"
	global otherMandates "hepB_Kmandate hepB_MSmandate hepA_CCmandate hepA_Kmandate hepA_MSmandate hib_mandate varic_CC_Kmandate varic_MSmandate varic_2mandate pcv_mandate flu_CCmandate rota_mandate mumps_mandate meas_2mandate menin_Bmandate"
	global Vacc_controls "MCV_boost MCVed_PS MCVed MCV_waiver MCV_PSmandate  exemp_pb wc_insure wc_insure_12yo imminsure imminsure_12yo HPVinsure HPVed_parent HPVed_stud HPVaware"	
	global styr "mdcd_upperlmt styr_perblack styr_perhispan styr_perother_eth styr_perfemale styr_perlt21 styr_per21_64 styr_HSrate styr_uni4rate styr_povrate unemp_rate"
	
	
	global LHS "tdap_search menin_vacc_search  hpv_search "
	drop if year<2005

	rename date date_string
	gen date = (year*12)+ month
	****************************************************
	
	foreach var of global LHS{
	quietly{
	 reg `var' menin_rate menin_lag pert_rate pert_lag $VaccMandates $otherMandates $Vacc_controls $styr i.date i.fips [aw=total_pop] if `var'!=0, vce(cluster fips)
	}
	tab year if e(sample)==1
	sum `var' if e(sample)==1 & year==2005 [aw=total_pop] 
	sum `var' if e(sample)==1 & year==2013 [aw=total_pop] 
	}
	
	/*TABLE 6*/ 
	estimates clear	
	foreach var of global LHS{
	quietly{
	
	eststo: reg `var' $VaccMandates menin_rate menin_lag pert_rate pert_lag  $otherMandates $Vacc_controls $styr i.date i.fips [aw=total_pop] if `var'!=0 & year<2014, vce(cluster fips)
	estadd ysumm
	estadd local lin "2005- 2013, No"
	
	eststo: reg `var' $VaccMandates menin_rate menin_lag pert_rate pert_lag  $otherMandates $Vacc_controls $styr i.date i.fips $linear [aw=total_pop] if `var'!=0 & year<2014, vce(cluster fips)
	estadd ysumm
	estadd local lin "2005- 2013, Yes"

	}
	}
	esttab est*  using "$output\gtrends_05172018.rtf", append keep(TDcont_mandate  pert_rate) /*
	*/ se  star(* 0.10 ** 0.05 *** 0.01) stats(lin N r2 ymean, label("State linear trend" "Observations" "R-Squared" "Mean of Dependent")) title(Effects of mandates on `var' monthly search volume) /*
	*/ note("All columns are weighted, have state and month-year fixed effects. SE are clustered at the state level.")
	
	
	/*APPENDIX TABLE 13*/
	estimates clear
	foreach var of global LHS{
	quietly{
	eststo: reg `var' menin_rate menin_lag pert_rate pert_lag $es_TDcont $es_MCV HPV_mandate $otherMandates $Vacc_controls $styr i.date i.fips [aw=total_pop] if `var'!=0 & year<2014, vce(cluster fips)
	estadd ysumm
	estadd local lin "2005-2013, No"
	
	eststo: reg `var' menin_rate menin_lag pert_rate pert_lag $es_TDcont $es_MCV  HPV_mandate $otherMandates $Vacc_controls $styr i.date i.fips $linear [aw=total_pop] if `var'!=0 & year<2014, vce(cluster fips)
	estadd ysumm
	estadd local lin "2005-2013, Yes"

	}
	}
	esttab est* using "$output\gtrends_05172018.rtf", append wide keep($es_TDcont) /*
	*/ se label star(* 0.10 ** 0.05 *** 0.01) stats(lin N r2 ymean, label("State linear trend" "Observations" "R-Squared" "Mean of Dependent")) title(Effects of mandates on `var' monthly search volume) /*
	*/ note("All columns are weighted, have state and month-year fixed effects. SE are clustered at the state level.")
	
	
