
	/* **************************************************************************
	Name of file: 	morbid_baselinediseaseinteraction.do
	
	Author: 		Emily Lawler  - emily.lawler@uga.edu
										
	Project: 		Middle School Vaccination
	
	Introduction: 
				
				
	Last Edited:   06/2/2016 9:30 AM
	
	Files Used: morbid_analysisfile.dta
					
	Files Created: 
								
	NOTES:   
	This do-file tests for non-linear effects of mandates on disease incidence by baseline morbidity.
	To test this I will try interacting the policy variable with 3 different things:
	(1) Baseline as morbidity in year prior to mandate (with pre 2004 states dropping out bc missing)
	(2) Baseline as morbidity in year prior to vaccine development (2004)
	(3) Baseline as morbidity in year prior to mandate with pre 2004 states being assigned 2004 morbidity
	*************************************************************************** */
	
	capture clear
	capture log close 
	capture clear matrix
	set more off 
	estimates clear
	
* +++++++++++++++++++++++++++++++++++
	* Secondary Globals - Dont change this! - 

global data     "$root/Data"
global NISdata  "$root/Data/NIS Teen"
global data2 	"$root/Data/Background"
global output   "$root\Output"
global tables   "$root/Output/Tables"
global figures  "$root/Output/Figures"
global dofiles  "$root/Do files"
global dofiles2 "$root/Do files/Background"
global logs 	"$root/Logs"
* +++++++++++++++++++++++++++++++++++

global agegrp "0_4 5_9 10_14 15_19 20_24 25_29 30_34 35_39 40_44 45_49 50_54 55_59 60_64 65plus"
	
	
	use "$data\morbid_analysisfile.dta", clear
	keep fips year pert0_4_rate pert5_9_rate pert10_14_rate pert15_19_rate pert20_24_rate pert25_29_rate pert30_34_rate pert35_39_rate pert40_44_rate pert45_49_rate pert50_54_rate pert55_59_rate pert60_64_rate pert65plus_rate pert_rate
	rename pert_rate pertrate_tneg1 
	foreach age of global agegrp{
	rename pert`age'_rate pert`age'_rate_tneg1
	}
	replace year = year+1 //so, for example, the 2004 values get merged onto the 2005 adopters
	rename year TDcont_yr
	tempfile cdc_tneg1
	save `cdc_tneg1'
	clear
	
	use "$data\morbid_analysisfile.dta", clear
	keep fips year pert0_4_rate pert5_9_rate pert10_14_rate pert15_19_rate pert20_24_rate pert25_29_rate pert30_34_rate pert35_39_rate pert40_44_rate pert45_49_rate pert50_54_rate pert55_59_rate pert60_64_rate pert65plus_rate pert_rate
	keep if year==2004
	
	rename pert_rate pertrate_2004 
	foreach age of global agegrp{
	rename pert`age'_rate pert`age'_rate_2004
	}
	tempfile cdc_2004
	save `cdc_2004'
	clear


 use "$data\morbid_analysisfile.dta", clear
 
 
 //gen TDcont_yr = Tdap_yr
	replace TDcont_yr = TD_yr if TD_yr<Tdap_yr //recall: missing values take +infinity in logical statements 

//2 states have TDcont_yr as pre-2004
/*To test for non-linear effects by baseline morbidity, Itry 2 different things:
	(1) Baseline as morbidity in year prior to vaccine development (2004)
	(2) Baseline as morbidity in year prior to mandate with pre 2004 states dbeing assigned 2004 morbidity (2004 is year prior to *Tdap* vaccine approval, before then there was only the TD vaccine)
*/
drop _merge

merge m:1 fips TDcont_yr using `cdc_tneg1',  keep(master matched)
	ren _merge _merge9
	
merge m:1 fips using `cdc_2004',  keep(master matched)
	ren _merge _merge10
	
gen pertrate_tneg1B = pertrate_tneg1
		replace pertrate_tneg1B = pertrate_2004 if TDcont_yr<2004
	
gen TDmandateXprneg1 = TDcont_mandate * pertrate_tneg1
	replace TDmandateXprneg1 = 0 if TDcont_yr==.
	
	
gen TDmandateXpr2004 = TDcont_mandate * pertrate_2004

gen TDmandateXprneg1B = TDcont_mandate * pertrate_tneg1B
	replace TDmandateXprneg1B = 0 if TDcont_yr==.

foreach age of global agegrp{
gen TDmandateXpr`age'_2004 = TDcont_mandate * pert`age'_rate_2004
gen TDmandateXpr`age'_neg1B = TDcont_mandate * pert`age'_rate_tneg1
	replace TDmandateXpr`age'_neg1B = 0 if TDcont_yr==.
}


	gen trend = year-2001
	gen trend_sq = trend*trend
	gen trend_cu = trend*trend*trend
	
	xi i.fips*trend i.fips*trend_sq i.fips*trend_cu 
	
	global linear "_IfipXtren_*"
	global quadratic "_IfipXtren_* _IfipXtrena*"
	global cubic "_IfipXtren_* _IfipXtrena* _IfipXtrenb*"
		

	
	//lagged versions of MCV vars
	gen MCV_boost = 0
	replace MCV_boost = 1 if m_MCVboost>=1 & m_MCVboost!=.

	gen MCVed_PS = 0
	replace MCVed_PS = 1 if m_MCVed_PS>=1 & m_MCVed_PS!=.

	gen MCVed = 0
	replace MCVed = 1 if m_MCVed>=1 & m_MCVed!=.

	gen MCV_waiver = 0
	replace MCV_waiver = 1 if m_MCV_PS>=1 & MCV_waiver_any==1

	gen MCV_PSmandate = 0
	replace MCV_PSmandate = 1 if m_MCV_PS>=1 & MCV_PSmandate_any==1
	

	
	global VaccMandates "MCV_mandate HPV_mandate"
	global otherMandates "hepB_Kmandate hepB_MSmandate hepA_CCmandate hepA_Kmandate hepA_MSmandate hib_mandate varic_CC_Kmandate varic_MSmandate varic_2mandate pcv_mandate flu_CCmandate rota_mandate mumps_mandate meas_2mandate menin_Bmandate"
	global Vacc_controls "MCV_boost MCVed_PS MCVed MCV_waiver MCV_PSmandate exemp_pb wc_insure wc_insure_12yo imminsure imminsure_12yo HPVinsure HPVed_parent HPVed_stud HPVaware"	
	global styr "mdcd_upperlmt styr_perblack styr_perhispan styr_perother_eth styr_perfemale styr_perlt21 styr_per21_64 styr_HSrate styr_uni4rate styr_povrate unemp_rate"
		
	
	****************************************************

	tab year, gen(year_)
	local treat1 "TDcont_mandate TDmandateXpr2004"
	local treat2 "TDcont_mandate TDmandateXprneg1B"

	/*APPENDIX TABLE 3*/
	estimates clear
	forvalues i=1/2{
	
	eststo: reg pert_rate pert_rate_lag `treat`i'' $VaccMandates $otherMandates $Vacc_controls $styr year_3-year_17 i.fips [aw=total_pop], vce(cluster fips)
	estadd ysumm
	estadd local lin "No"
	estadd local yr "2001-2015"
	
	eststo: reg pert_rate pert_rate_lag `treat`i'' $VaccMandates $otherMandates $Vacc_controls $styr year_3-year_17 i.fips $linear [aw=total_pop], vce(cluster fips)
	estadd ysumm
	estadd local lin "Yes"
	estadd local yr "2001-2015"

	}
	esttab est* using "$output\morbid_appendix_table3_01152018.rtf", append keep(`treat1' `treat2' pert_rate_lag) /* 
	*/ se label star(* 0.10 ** 0.05 *** 0.01) stats(lin yr N r2 ymean, label("State linear trend" "Sample years:" "Observations" "R-Squared" "Mean of Dependent")) title(Effects of mandates on `d' incidence) /*
	*/ note("All columns are weighted, have state and birth cohort fixed effects. SE are clustered at the state level.")
	
	******************************************************************

