
	/* **************************************************************************
	Name of file: 	morbidity_analysis.do
	
	Author: 		Emily Lawler  - emily.lawler@uga.edu
										
	Project: 		Middle School Vaccination
	
	Introduction: 
				
				
	Last Edited:   01/15/2018 9:30 AM
	
	Files Used: Morbidity analysis file
					
	Files Created: 
								
	NOTES:   
	1)  Generates all morbidity outcome paper tables
	*************************************************************************** */
	
	capture clear
	capture log close 
	capture clear matrix
	set more off 
	estimates clear
	

* +++++++++++++++++++++++++++++++++++

global data     "$root/Data"
global NISdata  "$root/Data/NIS Teen"
global data2 	"$root/Data/Background"
global output   "$root/Output"
global tables   "$root/Output/Tables"
global figures  "$root/Output/Figures"
global dofiles  "$root/Do files"
global dofiles2 "$root/Do files/Background"
global logs 	"$root/Logs"
* +++++++++++++++++++++++++++++++++++

 use "$data\morbid_analysisfile.dta", clear

	gen trend = year-2001
	gen trend_sq = trend*trend
	gen trend_cu = trend*trend*trend
	
	xi i.fips*trend i.fips*trend_sq i.fips*trend_cu 
	
	global linear "_IfipXtren_*"
	global quadratic "_IfipXtren_* _IfipXtrena*"
	global cubic "_IfipXtren_* _IfipXtrena* _IfipXtrenb*"
		
	global agegrp "0_4 5_9 10_14 15_19 20_24 25_29 30_34 35_39 40_44 45_49 50_54 55_59 60_64 65plus"
	
	
	global MS_vacc "Tdap TDcont MCV HPV"
	//event study specification, omitting year prior
	foreach var of global MS_vacc{
	global es1_`var' " M_`var'_ltneg5 M_`var'_neg5 M_`var'_neg4 M_`var'_neg3 M_`var'_neg2 M_`var'_0 M_`var'_1 M_`var'_2 M_`var'_3 M_`var'_4  M_`var'_gte5"
	}
	
		
	//lagged versions of MCV vars
	gen MCV_boost = 0
	replace MCV_boost = 1 if m_MCVboost>=1 & m_MCVboost!=.

	gen MCVed_PS = 0
	replace MCVed_PS = 1 if m_MCVed_PS>=1 & m_MCVed_PS!=.

	gen MCVed = 0
	replace MCVed = 1 if m_MCVed>=1 & m_MCVed!=.

	gen MCV_waiver = 0
	replace MCV_waiver = 1 if m_MCV_PS>=1 & MCV_waiver_any==1

	gen MCV_PSmandate = 0
	replace MCV_PSmandate = 1 if m_MCV_PS>=1 & MCV_PSmandate_any==1

	
	//log measures of disease incidence and population
	gen ln_pert = ln(pert_tot)
	gen ln_pop = ln(total_pop)
	
	foreach age of global agegrp{
	gen ln_pert`age'= ln(pert`age'+1)
	gen ln_pop`age' = ln(pop`age')
	}	
	
		gen pop5_14 = pop5_9 + pop10_14
gen pop15_24 = pop15_19 + pop20_24
gen pop25_34 = pop25_29 + pop30_34
gen pop35_44 = pop35_39 + pop40_44
gen pop45_54 = pop45_49 + pop50_54
gen pop55_64 = pop55_59 + pop60_64

global d2 "pert"
foreach var of global d2 {
gen `var'5_14 = `var'5_9 + `var'10_14
gen `var'15_24 = `var'15_19 + `var'20_24
gen `var'25_34 = `var'25_29 + `var'30_34
gen `var'35_44 = `var'35_39 + `var'40_44
gen `var'45_54 = `var'45_49 + `var'50_54
gen `var'55_64 = `var'55_59 + `var'60_64
}

global agegrp2a "0_4 5_14 15_24 25_34 35_44 45_54 55_64 65plus"
global agegrp2b "5_14 15_24 25_34 35_44 45_54 55_64"

foreach age of global agegrp2b{
	gen pert`age'_rate = pert`age'/pop`age' *100000
	gen ln_pert`age' = ln(pert`age' + 1)
	gen ln_pop`age' = ln(pop`age')
}	
foreach age of global agegrp2a{
	gen ln_tb`age' = ln(tb_`age' + 1 )
}	
	
	global VaccMandates "TDcont_mandate MCV_mandate HPV_mandate"
	global otherMandates "hepB_Kmandate hepB_MSmandate hepA_CCmandate hepA_Kmandate hepA_MSmandate hib_mandate varic_CC_Kmandate varic_MSmandate varic_2mandate pcv_mandate flu_CCmandate rota_mandate mumps_mandate meas_2mandate menin_Bmandate"
	global Vacc_controls "MCV_boost MCVed_PS MCVed MCV_waiver MCV_PSmandate exemp_pb wc_insure wc_insure_12yo imminsure imminsure_12yo HPVinsure HPVed_parent HPVed_stud HPVaware "	
	global styr "mdcd_upperlmt styr_perblack styr_perhispan styr_perother_eth styr_perfemale styr_perlt21 styr_per21_64 styr_HSrate styr_uni4rate styr_povrate unemp_rate"
	global disease "pert" 
	
	
	****************************************************
	/* APPENDIX TABLE 1: Descriptive statistics */
	
	quietly{
		eststo: reg pert_rate pert_rate_lag $es2_TDcont $es2_MCV HPV_mandate $otherMandates $Vacc_controls $styr i.year i.fips [aw=total_pop], vce(cluster fips)
	}
	
	sum pert_rate pert5_14_rate [aw=total_pop] if e(sample)==1
	sum pert_rate pert5_14_rate [aw=total_pop] if (tdap_any==1|td_MS==1) & e(sample)==1
	sum pert_rate pert5_14_rate [aw=total_pop] if (tdap_any==0& td_MS==0) & e(sample)==1
	

	tab year, gen(year_)
	
	/*Table 1: Effects on Pertussis Incidence */
	
	foreach d of global disease{
	estimates clear
	
	eststo: reg `d'_rate `d'_rate_lag $VaccMandates $otherMandates $Vacc_controls $styr year_3-year_17 i.fips [aw=total_pop], vce(cluster fips)
	estadd ysumm
	estadd local lin "No"
	estadd local yr "2001-2015"
	
	eststo: reg `d'_rate `d'_rate_lag $VaccMandates $otherMandates $Vacc_controls $styr year_3-year_17 i.fips $linear [aw=total_pop], vce(cluster fips)
	estadd ysumm
	estadd local lin "Yes"
	estadd local yr "2001-2015"
	
	esttab est* using "$output\morbid_01152018.rtf", append keep(TDcont_mandate) /* 
	*/ se label star(* 0.10 ** 0.05 *** 0.01) stats(lin yr N r2 ymean, label("State linear trend" "Sample years:" "Observations" "R-Squared" "Mean of Dependent")) title(Effects of mandates on `d' incidence) /*
	*/ note("All columns are weighted, have state and birth cohort fixed effects. SE are clustered at the state level.")
	}
		
	

		
	/*Table 2: RESULTS BY AGE GROUP */ 
	
foreach age of global agegrp2a{
	estimates clear
	
	eststo: reg pert`age'_rate pert_rate_lag $VaccMandates $otherMandates $Vacc_controls $styr i.year i.fips [aw=pop`age'] if year>=2001 & year<=2015, vce(cluster fips)
	estadd ysumm
	estadd local lin "No"
	estadd local yr "2001-2015" 
	
	eststo: reg pert`age'_rate pert_rate_lag $VaccMandates $otherMandates $Vacc_controls $styr i.year i.fips $linear [aw=pop`age'] if year>=2001 & year<=2015, vce(cluster fips)
	estadd ysumm
	estadd local lin "Yes"
	estadd local yr "2001-2015" 
	
	esttab est* using  "$output\morbid_01152018.rtf", append /*wide*/ keep(TDcont_mandate) /*
	*/ se label star(* 0.10 ** 0.05 *** 0.01) stats(lin yr N r2 ymean, label("State linear trend" "Sample years:" "Observations" "R-Squared" "Mean of Dependent")) title(Effects of mandates on pert incidence, `age' agegrp) /*
	*/ note("All columns are weighted by age-specific pop, have state and birth cohort fixed effects. SE are clustered at the state level.")
}

foreach age of global agegrp2a{
		 estimates clear
		
	eststo: reg tb_rate_`age' pert_rate_lag $VaccMandates $otherMandates $Vacc_controls $styr i.year i.fips [aw=pop`age'] if year>=2001 & year<=2015, vce(cluster fips)
	estadd ysumm
	estadd local lin "No"
	estadd local yr "2001-2014" 
	
	eststo: reg tb_rate_`age' pert_rate_lag $VaccMandates $otherMandates $Vacc_controls $styr i.year i.fips $linear [aw=pop`age'] if year>=2001 & year<=2015, vce(cluster fips)
	estadd ysumm
	estadd local lin "Yes"
	estadd local yr "2001-2014" 

	esttab est* using  "$output\morbid_01152018.rtf", append /*wide*/ keep(TDcont_mandate) /*
	*/ se label star(* 0.10 ** 0.05 *** 0.01) stats(lin yr N r2 ymean, label("State linear trend" "Sample years:" "Observations" "R-Squared" "Mean of Dependent")) title(Effects of mandates on `d' incidence, `age' agegrp) /*
	*/ note("All columns are weighted by age-specific pop, have state and birth cohort fixed effects. SE are clustered at the state level.")
}



	
	* FIGURE 5 // APPENDIX TABLE 4: Event study
		local es1 "$es1_TDcont $es1_MCV"
		
	
	estimates clear
	eststo: reg pert_rate pert_rate_lag `es1' HPV_mandate $otherMandates $Vacc_controls $styr i.year i.fips [aw=total_pop], vce(cluster fips)
	estadd ysumm
	estadd local lin "No"
	
	eststo: reg pert_rate pert_rate_lag `es1'  HPV_mandate $otherMandates $Vacc_controls $styr i.year i.fips $linear [aw=total_pop], vce(cluster fips)
	estadd ysumm
	estadd local lin "Yes"
	
	
	esttab est1 est2 using  "$output\morbid_01152018.rtf", append keep( M_TDcont*) /*
	*/ se label star(* 0.10 ** 0.05 *** 0.01) stats(lin N r2 ymean, label("State linear trend" "Observations" "R-Squared" "Mean of Dependent")) title(Event study estimates of effects of mandates) /*
	*/ note("All columns are weighted, have state and birth cohort fixed effects. SE are clustered at the state level.")
	
	
	* APPENDIX TABLE 5: Effects on other diseases at population level 
	
		estimates clear
	foreach var of varlist pert_rate hepa_rate hepb_rate menin_rate tb_rate meas_rate lyme_rate salm_rate  {

	eststo: reg `var' pert_rate_lag $VaccMandates $otherMandates $Vacc_controls $styr i.year i.fips [aw=total_pop] if year>=2001 & year<=2015, vce(cluster fips)
	estadd ysumm
	estadd local lin "No"

	}
	esttab est* using "$output\morbid_01152018.rtf", append keep(TDcont_mandate) /*
	*/ se label star(* 0.10 ** 0.05 *** 0.01) stats(lin N r2 ymean, label("State linear trend" "Observations" "R-Squared" "Mean of Dependent")) title(Effects of mandates on menin. incidence) /*
	*/ note("All columns are weighted, have state and birth cohort fixed effects. SE are clustered at the state level.")
	
	


	****************************************************************************
	* Robustness 
	
	
	//EXTRA TABLE: using log morbidity specifications 
	
	estimates clear
		eststo: reg ln_pert ln_pop pert_rate_lag $VaccMandates $otherMandates $Vacc_controls $styr i.year i.fips [aw=total_pop], vce(cluster fips)
	estadd ysumm
	estadd local lin "No"
	estadd local yr "2001-2015"
	
	eststo: reg ln_pert ln_pop pert_rate_lag $VaccMandates $otherMandates $Vacc_controls $styr i.year i.fips $linear [aw=total_pop], vce(cluster fips)
	estadd ysumm
	estadd local lin "Yes"
	estadd local yr "2001-2015"
	
	eststo: reg ln_pert5_14 ln_pop5_14 pert_rate_lag $VaccMandates $otherMandates $Vacc_controls $styr i.year i.fips [aw=pop5_14] if year>=2001 & year<=2015, vce(cluster fips)
	estadd ysumm
	estadd local lin "No"
	estadd local yr "2001-2015" 
	
	eststo: reg ln_pert5_14 ln_pop5_14 pert_rate_lag $VaccMandates $otherMandates $Vacc_controls $styr i.year i.fips $linear [aw=pop5_14] if year>=2001 & year<=2015, vce(cluster fips)
	estadd ysumm
	estadd local lin "Yes"
	estadd local yr "2001-2015" 
	
	esttab est* using "$output\morbid_01152018.rtf", append keep(TDcont_mandate ln_pop*) /*
	*/ se label star(* 0.10 ** 0.05 *** 0.01) stats(lin yr N r2 ymean, label("State linear trend" "Sample years:" "Observations" "R-Squared" "Mean of Dependent")) title(Effects of mandates on `d' incidence) /*
	*/ note("All columns are weighted, have state and birth cohort fixed effects. SE are clustered at the state level.")


	

	//EXTRA TABLE: no weights
	
	estimates clear
	
	eststo: reg pert_rate pert_rate_lag  $VaccMandates $otherMandates $Vacc_controls $styr i.year i.fips , vce(cluster fips)
	estadd ysumm
	estadd local lin "No"
	
	eststo: reg pert_rate pert_rate_lag $VaccMandates $otherMandates $Vacc_controls $styr i.year i.fips $linear, vce(cluster fips)
	estadd ysumm
	estadd local lin "Yes"
	
	eststo: reg pert5_14_rate pert_rate_lag  $VaccMandates $otherMandates $Vacc_controls $styr i.year i.fips , vce(cluster fips)
	estadd ysumm
	estadd local lin "No"
	
	eststo: reg pert5_14_rate pert_rate_lag $VaccMandates $otherMandates $Vacc_controls $styr i.year i.fips $linear, vce(cluster fips)
	estadd ysumm
	estadd local lin "Yes"
	
	esttab est* using "$output\morbid_01152018.rtf", append keep(TDcont_mandate) /*
	*/ se label star(* 0.10 ** 0.05 *** 0.01) stats(lin yr N r2 ymean, label("State linear trend" "Observations" "R-Squared" "Mean of Dependent")) title(Robustness: Effects of mandates on `d' incidence, unweighted) /*
	*/ note("All columns are weighted, have state and birth cohort fixed effects. SE are clustered at the state level.")
	
	
	
	//EXTRA TABLE:no state-year controls
				
	estimates clear
	
	eststo: reg pert_rate pert_rate_lag  $VaccMandates $otherMandates $Vacc_controls i.year i.fips [aw=total_pop], vce(cluster fips)
	estadd ysumm
	estadd local lin "No"
	
	eststo: reg pert_rate pert_rate_lag $VaccMandates $otherMandates $Vacc_controls  i.year i.fips $linear [aw=total_pop], vce(cluster fips)
	estadd ysumm
	estadd local lin "Yes"
	
	eststo: reg pert5_14_rate pert_rate_lag  $VaccMandates $otherMandates $Vacc_controls i.year i.fips [aw=pop5_14], vce(cluster fips)
	estadd ysumm
	estadd local lin "No"
	
	eststo: reg pert5_14_rate pert_rate_lag $VaccMandates $otherMandates $Vacc_controls  i.year i.fips $linear [aw=pop5_14], vce(cluster fips)
	estadd ysumm
	estadd local lin "Yes"
	
	esttab est* using "$output\morbid_01152018.rtf", append keep(TDcont_mandate) /*
	*/ se label star(* 0.10 ** 0.05 *** 0.01) stats(lin yr N r2 ymean, label("State linear trend" "Observations" "R-Squared" "Mean of Dependent")) title(Robustness: Effects of mandates on `d' incidence, omitting state X's) /*
	*/ note("All columns are weighted, have state and birth cohort fixed effects. SE are clustered at the state level.")
	
	
	
	//MAIN RESULTS, with controls for section 317 funds, VFC policy, pharmacist vac authority
	local rb1 "s317_total"
	local rb2 "vfc_underins vfc_underins_select vfc_uni vfc_unisel vfc_other"
	local rb3 "gaOrx"
		
	forvalues i=1/3{
	estimates clear
	eststo: reg pert_rate pert_rate_lag `rb`i'' $VaccMandates $otherMandates $Vacc_controls $styr i.year i.fips [aw=total_pop], vce(cluster fips)
	estadd ysumm
	estadd local lin "No"
	
	
	eststo: reg pert_rate pert_rate_lag `rb`i'' $VaccMandates $otherMandates $Vacc_controls $styr i.year i.fips $linear [aw=total_pop], vce(cluster fips)
	estadd ysumm
	estadd local lin "Yes"
	
	eststo: reg pert5_14_rate pert_rate_lag `rb`i'' $VaccMandates $otherMandates $Vacc_controls $styr i.year i.fips [aw=pop5_14], vce(cluster fips)
	estadd ysumm
	estadd local lin "No"
	
	
	eststo: reg pert5_14_rate pert_rate_lag `rb`i'' $VaccMandates $otherMandates $Vacc_controls $styr i.year i.fips $linear [aw=pop5_14], vce(cluster fips)
	estadd ysumm
	estadd local lin "Yes"
	
	esttab est* using "$output\morbid_01152018.rtf", append keep(TDcont_mandate `rb`i'' ) /*
	*/ se label star(* 0.10 ** 0.05 *** 0.01) stats(lin yr N r2 ymean, label("State linear trend" "Observations" "R-Squared" "Mean of Dependent")) title(Robustness: Effects of mandates on `d' incidence, including section 317 and vfc controls ) /*
	*/ note("All columns are weighted, have state and birth cohort fixed effects. SE are clustered at the state level.")
	
	}
	
	
	
//graphs of pertussis incidence in US by year	
sort year	

collapse (sum) pert_tot total_pop, by(year)
gen pert_rate = (pert_tot/total_pop)*100000
drop if year==2016
twoway (connected pert_rate year, lpattern(solid) lcolor(blue) mcolor(blue) msymbol(o)), /*
		*/ graphregion(fcolor(white)) ylabel(, nogrid angle(horizontal) ) /* 
		*/ scheme(s2mono) xline(`impyr') /*
		*/ yscale( nofextend ) xscale(nofextend) xlabel(2001(2)2015) /*
		*/ xtitle("Year") ytitle("Pertussis Rate per 100,000 population") /*title("Pertussis Incidence Rate in United States")*/  note("CDC surveillance data.") 
	
	graph export "$output\Figure2_pertussis_trends_notitle.wmf", as(wmf) replace


