/* **************************************************************************
	Name of file: 	morbidity_prep.do
	
	Author: 		Emily Lawler  - emily.lawler@uga.edu
										
	Project: 		Middle School Vaccination
	
	Introduction: 
				
				
	Last Edited:   08/22/2016 9:30 AM
	
	Files Used: 
					
	Files Created: 
								
	NOTES:   
	1) 
	*************************************************************************** */
	
	capture clear
	capture log close 
	capture clear matrix
	set more off 
	estimates clear
	

* +++++++++++++++++++++++++++++++++++

global data     "$root/Data"
global NISdata  "$root/Data/NIS Teen"
global data2 	"$root/Data/Background"
global output   "$root/Output"
global tables   "$root/Output/Tables"
global figures  "$root/Output/Figures"
global dofiles  "$root/Do files"
global dofiles2 "$root/Do files/Background"
global logs 	"$root/Logs"
* +++++++++++++++++++++++++++++++++++
	
//MS mandates
	import excel using "$data\MS Mandate policy data tables.xlsx", sheet("Tdap & MCV") firstrow clear

	gen TDcont_yr = tdap_yr
	replace TDcont_yr = td_yr if td_yr<=tdap_yr & td_MS==1
	replace td_MS=0 if td_MS==.
	replace tdap_allMSgr = 0 if tdap_allMSgr==.	

	//code in the DC and Virginia school mandates
	gen HPV_yr=.
	replace HPV_yr=2008 if fips==51 //VA mandate effective Oct 2008, applies to 6th grade
	replace HPV_yr=2009 if fips==11 //DC mandate effective Aug 09, for 6th-12th grade
	
	
	drop  tdap_minage tdap_year12  td_year12
	rename td_yr TD_yr
	rename tdap_yr Tdap_yr
	tempfile tdap_mcv_hpv_policy
	save `tdap_mcv_hpv_policy'
	clear

	//all other mandates, with year of implementation
import excel using "$data\MS Mandate policy data tables.xlsx", sheet("other mandates, year of implem.") firstrow clear
destring, replace
drop if fips==.
tempfile other_mandates
save `other_mandates'
clear

	//Insurance mandates: broad immunization coverage and well-child visits
import excel using "$data2\Vaccination and well child Insurance Mandates.xlsx", sheet("Well Child & Imm mandates") cellrange(A4:V55) firstrow clear

rename preACAimmunizationmandate preACA_imminsure
keep fips imminsure_month imminsure_year preACA_wc preACA_wc_12yo  preACA_imminsure preACA_imminsure_12yo
destring, replace
replace preACA_wc = 0 if preACA_wc==.
replace preACA_wc_12yo=0 if preACA_wc_12yo==.

replace preACA_imminsure=0 if preACA_imminsure==.
replace preACA_imminsure_12yo=0 if preACA_imminsure_12yo==.

label var preACA_wc "=1 if state had preACA wc mandate"
label var preACA_wc_12yo "=1 if state had preACA wc mandate that applied to 12yo"

label var preACA_imminsure "=1 if state had preACA imm insure mandate"
label var preACA_imminsure_12yo "=1 if state had preACA imm insure mandate that applied to 12yo"

gen WC_month=imminsure_month
gen WC_year = imminsure_year
replace WC_month=9 if preACA_wc==0
replace WC_year=2010 if preACA_wc==0

gen WC_month_12yo=imminsure_month
gen WC_year_12yo= imminsure_year
replace WC_month_12yo=9 if preACA_wc_12yo==0
replace WC_year_12yo=2010 if preACA_wc_12yo==0

gen imminsure_month_12yo=imminsure_month
gen imminsure_year_12yo=imminsure_year
replace imminsure_month_12yo=9 if preACA_imminsure_12yo==0
replace imminsure_year_12yo=2010 if preACA_imminsure_12yo==0


tempfile insure_policy
save `insure_policy'
clear

	//HPV-specific insurance mandates
import excel using "$data2\state hpv insurance mandates.xlsx", sheet("Policy data for stata") cellrange(A4:R55) firstrow clear
keep fips HPVinsure_ever HPVinsure_month HPVinsure_year
replace HPVinsure_ever=0 if HPVinsure_ever==.
tempfile HPV_insure_policy
save `HPV_insure_policy'
clear

	//HPV-specific policies
import excel using "$data2\state hpv insurance mandates.xlsx", sheet("HPV funding & ed") cellrange(A3:K54) firstrow clear
keep fips  HPVed_parent_yr HPVed_stud_yr  HPVaware_yr HPVpharm_yr
tempfile HPV_policy2
save `HPV_policy2'
clear
		//nme policies (note: this spreadsheet is the policies that were effective as of 2015. 3 states had effective policy changes that occurred between 2001-2015)
import excel using "$data2\nme policy.xlsx", cellrange(A2:G53) firstrow clear
keep state fips exemp_relig exemp_pb
tempfile nme_policy_2014
save `nme_policy_2014'
clear
	
* Create one file with all vaccine related policy information

use "$data2\state_yr_obs00_15.dta", clear //dataset containing only state/fips/year obs for 2001-2015
merge 1:1 fips year using "$data2\seerpop.dta", nogen keep(master matched)

merge m:1 fips using `tdap_mcv_hpv_policy' 
	ren _merge _merge1
merge m:1 fips using `other_mandates' //NOTE: these are state observations containing year of implementation
	ren _merge _merge2
drop if fips==.
drop _merge*


merge m:1 fips using `nme_policy_2014'
	ren _merge _merge1
	replace exemp_pb=0 if fips==48 & year<=2002 //Texas added pb exemp in 2003
	replace exemp_pb=0 if fips==5 & year<=2002 //Arkansas added pb exemp in 2003
	replace exemp_pb=1 if fips==35 & year<2013 //NM removed pb exemp in 2013
	
	
merge m:1 fips using `insure_policy'
	ren _merge _merge2
	gen imminsure = 0
	replace imminsure=1 if year>imminsure_year //1 year-lag (ignoring month info)
	label var imminsure "=1 if state has lagged effective imm insure mandate"
	gen imminsure_12yo = 0
	replace imminsure_12yo=1 if year>imminsure_year_12yo 
	label var imminsure_12yo "=1 if state has lagged effective imm insure mandate, 12yo"
	
	gen wc_insure = 0
	replace wc_insure=1 if year>WC_year //again, 1 year-lag (ignoring month)
	label var wc_insure "=1 if state has lagged effective wc insure mandate"
	gen wc_insure_12yo = 0
	replace wc_insure_12yo=1 if year>WC_year_12yo
	label var wc_insure_12 "=1 if state has lagged effective wc insure mandate, 12yo"
	
	drop preACA_*
	
merge m:1 fips using `HPV_insure_policy'
	ren _merge _merge3
	gen HPVinsure = 0
	replace HPVinsure =1 if year>HPVinsure_year & HPVinsure_year!=. //1 year-lag(ignoring month info), NOT turning on for all with ACA 
	label var HPVinsure "=1 if state has lagged effective HPV insure mandate"
	
merge m:1 fips using `HPV_policy2'
	ren _merge _merge4
	gen HPVed_parent = 0
	replace HPVed_parent =1 if year>HPVed_parent_yr & HPVed_parent_yr!=. //1 year-lag
	label var HPVed_parent "=1 if state has lagged effective HPV parent ed mandate"
	
	gen HPVed_stud = 0
	replace HPVed_stud =1 if year>HPVed_stud_yr & HPVed_stud_yr!=. //1 year-lag
	label var HPVed_stud "=1 if state has lagged effective HPV student ed"
		
	gen HPVaware = 0
	replace HPVaware =1 if year>HPVaware_yr & HPVaware_yr!=. //1 year-lag
	label var HPVaware "=1 if state has had an HPV awareness campaign, lagged 1 year "
	
	replace HPVpharm_yr = "2008" if HPVpharm_yr=="≤2008" //Note: The HPV pharmacist control is only known as of 2008, so NOT to be used as a control for time periods prior to 2008	
	destring HPVpharm_yr, replace
	gen HPVpharm = 0
	replace HPVpharm =1 if year>HPVpharm_yr & HPVpharm_yr!=. //1 year-lag
	label var HPVpharm "=1 if state has lagged effective authority for pharmacist to admin HPV"
	
	
	drop _merge*
	
//create variables that capture number of years relative to implementation year
gen m_Tdap = year- Tdap_yr
gen m_MCV = year - MCV_yr
gen m_TDcont = year - TDcont_yr
gen m_HPV = year - HPV_yr

//MCV education, booster, and college policies
destring MCV_boost_yr MCVed_yr MCVed_PS_yr MCV_PS_yr, replace
gen m_MCVboost = year - MCV_boost_yr
gen m_MCVed = year - MCVed_yr
gen m_MCVed_PS = year - MCVed_PS_yr
gen m_MCV_PS = year - MCV_PS_yr

global otherMandates "hepB_K hepB_MS hepA_CC hepA_K hepA_MS hib_ varic_CC_K varic_MS varic_2 pcv_ flu_CC rota_ mumps_ meas_2 menin_B"
foreach man of global otherMandates{
gen m_`man'= year - `man'yr
gen `man'mandate =0
replace `man'mandate = 1 if m_`man'>=1 & m_`man'!=.
}

	//Dummy vars for if there is an effective mandate
gen Tdap_mandate = 0 //variable for Tdap specific
replace Tdap_mandate = 1 if m_Tdap>=1 & m_Tdap!=. //lagged
label var Tdap_mandate "current Tdap mandate, lagged"

gen TDcont_mandate = 0 //for TD-containing
replace TDcont_mandate = 1 if m_TDcont>=1 & m_TDcont!=.
label var TDcont_mandate "current TDcont mandate, lagged"

gen MCV_mandate = 0
replace MCV_mandate=1 if m_MCV>=1 & m_MCV!=.
label var MCV_mandate "current MCV mandate, lagged"

gen HPV_mandate= 0 
replace HPV_mandate=1 if m_HPV>=1 & m_HPV!=. 
label var HPV_mandate "current HPV mandate, lagged"


* Event study dummy vars
global MS_vacc "Tdap TDcont MCV HPV"
foreach var of global MS_vacc{
	forvalue i=1/5{
	gen M_`var'_neg`i' = 0
	replace M_`var'_neg`i' = 1 if m_`var'==-`i'
	}
	
	
	forvalue i=0/9{
	gen M_`var'_`i' = 0
	replace M_`var'_`i' = 1 if m_`var'==`i'
	}
	
	gen M_`var'_gt5 = 0 
	replace M_`var'_gt5 =1 if m_`var'>5 & m_`var'!=.
	
	gen M_`var'_gte5 = 0 
	replace M_`var'_gte5 =1 if m_`var'>=5 & m_`var'!=.
	
	
	gen M_`var'_gt7 = 0 
	replace M_`var'_gt7 =1 if m_`var'>7 & m_`var'!=.
	
	//create a policy dummy for m<-5
	gen M_`var'_ltneg5 = 0
	replace M_`var'_ltneg5 =1 if m_`var'<-5 & m_`var'!=.
	}


//add VFC (available only 2001-2010)
//add Section 317 funds (available only 1995-2003, 2007-2013)
	

	save "$data\vaccpolicy_st_yr.dta", replace
	
	*************************************
	
		//Section 317 funds only for 1995-2003, 2007-2013
	import excel using "$data2\Section 317 state funding 1995-2003, 2007-2013.xlsx", sheet("Stata ready") cellrange(A2:F819) firstrow clear
	drop state s317_DA s317_FA
	tempfile s317
	save `s317'
	clear

	//VFC measures only for 2000-2010
	import excel using "$data2\VFC policy 2001-2010.xlsx", cellrange(A1:I562) firstrow clear
	rename universal vfc_uni
	rename universal_select vfc_unisel
	rename Other vfc_other
	drop State
	destring, replace
		replace vfc_only=0 if vfc_only==.
		replace vfc_underins = 0 if vfc_underins==.
		replace vfc_underins_select = 0 if vfc_underins_select==.
		replace vfc_uni = 0 if vfc_uni==.
		replace vfc_unisel = 0 if vfc_unisel==.
		replace vfc_other = 0 if vfc_other==.
	tempfile vfc
	save `vfc'
	clear
		
		
	use "$data\vaccpolicy_st_yr.dta", clear
	merge 1:1 fips year using "$data\pert_2000_2015.dta", keep(master matched)
		ren _merge _merge1
	merge 1:1 fips year using "$data2\lawatlas_pharmlaws.dta", keep(master matched) keepusing(rx_pert rx_mcv rx_hpv ga_pert ga_mcv ga_hpv ps_pert ps_mcv ps_hpv)
		ren _merge _merge2
	merge 1:1 fips year using "$data\cdc_diseases_surv_1996_2015.dta", keep(master matched) keepusing(salm hepa hepb lyme measles menin tb*)	
		ren _merge _merge3
	merge 1:1 fips year using "$data2\st_yr_cps.dta", keep(master matched)
		ren _merge _merge4
			drop pop_*
	merge m:1 fips year using "$data2\BLS_st_yr.dta", keep(master matched)
		ren _merge _merge5
		drop pop
	merge m:1 fips year using "$data\medicaid_thresholds_2000_2015.dta", keep(master matched) keepusing(mdcd_upperlmt)
		ren _merge _merge6
	merge m:1 fips year using `vfc', keep(master matched) 
		ren _merge _merge7
	merge m:1 fips year using `s317', keep(master matched) 
		ren _merge _merge8
		
	drop _merge*
	
	
	//clean up/group together measures of pharmacist vaccination authority
	gen pharmlaw_miss = 0
	replace pharmlaw_miss = 1 if (rx_pert==.| rx_mcv==.| rx_hpv==.| ga_pert==.| ga_mcv==.| ga_hpv==.| ps_pert==.| ps_mcv==.| ps_hpv==.)
	
	global vars "rx_pert rx_mcv rx_hpv ga_pert ga_mcv ga_hpv ps_pert ps_mcv ps_hpv"
	foreach var of global vars{
	replace `var' = 0 if `var'==.
	} 
	
	gen gaOrx = ga_pert
		replace gaOrx=1 if rx_pert==1
		
		label var gaOrx "Pharmacist RX or general authority for pertussis, 11+ yr olds"
			
	
	global agegrp "0_4 5_9 10_14 15_19 20_24 25_29 30_34 35_39 40_44 45_49 50_54 55_59 60_64 65plus"
	
	gen total_pop = 0
	foreach age of global agegrp{
		replace total_pop = total_pop + pop`age'
	}
	
	gen salm_rate = (salm/total_pop)*100000
	gen pert_rate = (pert_tot/total_pop)*100000
	gen menin_rate = (menin/total_pop)*100000
	gen hepa_rate = (hepa/total_pop)*100000
	gen hepb_rate = (hepb/total_pop)*100000
	gen lyme_rate = (lyme/total_pop)*100000
	gen meas_rate = (measles/total_pop)*100000
	gen tb_rate = (tb/total_pop)*100000
	
	global agegrp "0_4 5_9 10_14 15_19 20_24 25_29 30_34 35_39 40_44 45_49 50_54 55_59 60_64 65plus"
	
	gen pert65plus = pert65_69 + pert70plus
	foreach age of global agegrp{
	gen pert`age'_rate = pert`age'/pop`age' *100000
	}	
	
	tempfile morbid_analysis_tmp
	save `morbid_analysis_tmp'
	
	//create lagged morbidity measures to merge in to full analysis file
	keep fips salm_rate pert_rate menin_rate year
	rename salm_rate salm_rate_lag
	rename pert_rate pert_rate_lag
	rename menin_rate menin_rate_lag
	replace year = year+1
	
	merge 1:1 fips year using `morbid_analysis_tmp'
	
	//code in medicaid expansion (as of jan 1 2017), from  http://kff.org/health-reform/state-indicator/state-activity-around-expanding-medicaid-under-the-affordable-care-act/"
		gen expandt = "1/1/2014"
                replace expandt = "" if fips==1 | fips==12 | fips==13 | fips==16 | fips==20 | fips==22 | fips==23 | fips==28 | fips==29 | fips==30 | fips==31 | fips==37 | fips==40 | fips==45 | fips==46 | fips==47 | fips==48 | fips==49 | fips==51 | fips==55 | fips==56
                replace expandt = "9/1/2015" if fips==2 | state=="AK"         /*Alaska (9/1/2015)*/
                replace expandt = "2/1/2015" if fips==18 | state=="IN"        /*Indiana (2/1/2015)*/
                replace expandt = "4/1/2014" if fips==26 | state=="MI"        /*Michigan (4/1/2014)*/
                replace expandt = "1/1/2016" if fips==30 | state=="MT"        /*Montana (1/1/2016)*/
					//replace expandt = "" if fips==30 | state=="MT"  			**I don't know why Sayeh coded this this way? It seems like Montana expanded Medicaid, although there is a note on KFF that MT is a Section 1115 waiver state...
                replace expandt = "8/15/2014" if fips==33 | state=="NH"       /*New Hampshire (8/15/2014)*/
                replace expandt = "1/1/2015" if fips==42 | state=="PA"        /*Pennsylvania (1/1/2015)*/
				replace expandt = "7/1/2016" if fips==22 //Louisiana
                label var expandt "Calendar month of expansion"
        cap drop temp
        gen temp = date(expandt, "MDY")
        gen cmexp = mofd(temp)
        format cmexp %tm
		gen obsdate = ym(year, 6)
        gen mdcdexpand= cmexp<obsdate
		label var mdcdexpand "=1 if a state has expanded medicaid by June of the calendar year"

	
	
	save "$data\morbid_analysisfile.dta", replace
	//have complete policy and morbidity data for 2001-2013
	//only have HPV pharmacist authority to vaccinate for 2008-2014, vfc 2000-2010, section 317 1995-2003, 2007-2013
	

	
