/* **************************************************************************
	Name of file: 	policy_prep1_year12.do
	
	Author: 		Emily Lawler  - emily.lawler@uga.edu
										
	Project: 		Middle School Vaccination
	
	Introduction: 
				
				
	Last Edited:   06/2/2016 9:30 AM
	
	Files Used: nme policy.xlsx, state hpv insurance mandates.xlsx, Vaccination and well child Insurance Mandates.xlsx, MS Mandate policy data tables.xlsx
					
	Files Created: vaccpolicy_st_yr12.dta
								
	NOTES:   
	1) Brings in policy variables from separate spreadsheets, generates one file that has vaccine policy coded at the state-year level
	2) Policies are coded based on YEAR12 (i.e. coded in effect if they applied to 12 year olds in a given year)
	*************************************************************************** */
	
	capture clear
	capture log close 
	capture clear matrix
	set more off 
	estimates clear
	
* +++++++++++++++++++++++++++++++++++

global data     "$root/Data"
global NISdata  "$root/Data/NIS Teen"
global data2 	"$root/Data/Background"
global output   "$root/Output"
global tables   "$root/Output/Tables"
global figures  "$root/Output/Figures"
global dofiles  "$root/Do files"
global dofiles2 "$root/Do files/Background"
global logs 	"$root/Logs"
* +++++++++++++++++++++++++++++++++++

*Bring in policy variable from excel spreadsheets	
	//main set of MS mandates
import excel using "$data\MS Mandate policy data tables.xlsx", sheet("Tdap & MCV") firstrow clear
replace tdap_allMSgr = 0 if tdap_allMSgr==.	
rename tdap_year12 Tdap_year12
rename td_year12 TD_year12

	//code in the DC and Virginia school mandates
gen HPV_year12=.
replace HPV_year12=2009 if fips==51 //VA mandate effective Oct 2008, applies to 6th grade
replace HPV_year12=2009 if fips==11 //DC mandate effective Aug 09, for 6th-12th grade
replace td_MS=0 if td_MS==.
tempfile tdap_mcv_hpv_policy
save `tdap_mcv_hpv_policy'
clear

	//all other mandates that potentially affect middle schoolers
import excel using "$data\MS Mandate policy data tables.xlsx", sheet("other MS mandates by year 12") firstrow clear
destring, replace
drop if fips==.
tempfile other_ms_mandates
save `other_ms_mandates'
clear

	//control for CONTEMPORANEOUS changes in childcare/kindergarten mandates
import excel using "$data\MS Mandate policy data tables.xlsx", sheet("other mandates, year of implem.") firstrow clear
destring, replace
drop if fips==.
drop hepB_MS* hepA_MS* varic_MS* varic_2* menin_B*
tempfile ccK_mandates
save `ccK_mandates'
clear

	//Insurance mandates: broad immunization coverage and well-child visits
import excel using "$data2\Vaccination and well child Insurance Mandates.xlsx", sheet("Well Child & Imm mandates") cellrange(A4:V55) firstrow clear
keep fips imminsure_month imminsure_year preACA_wc_12yo  preACA_imminsure_12yo
destring, replace
replace preACA_wc_12yo=0 if preACA_wc_12yo==.
replace preACA_imminsure_12yo=0 if preACA_imminsure_12yo==.

gen WC_month=imminsure_month
gen WC_year= imminsure_year

replace imminsure_month=9 if preACA_imminsure_12yo==0
replace imminsure_year=2010 if preACA_imminsure_12yo==0

replace WC_month=9 if preACA_wc_12yo==0
replace WC_year=2010 if preACA_wc_12yo==0
tempfile insure_policy
save `insure_policy'
clear

	//HPV-specific insurance mandates
import excel using "$data2\state hpv insurance mandates.xlsx", sheet("Policy data for stata") cellrange(A4:R55) firstrow clear
keep fips HPVinsure_ever HPVinsure_month HPVinsure_year
replace HPVinsure_ever=0 if HPVinsure_ever==.
tempfile HPV_insure_policy
save `HPV_insure_policy'
clear

import excel using "$data2\state hpv insurance mandates.xlsx", sheet("HPV funding & ed") cellrange(A3:K54) firstrow clear
keep fips  HPVed_parent_yr HPVed_stud_yr  HPVaware_yr HPVpharm_yr
tempfile HPV_policy2
save `HPV_policy2'
clear
		//nme policies (note: this spreadsheet is the policies that were effective as of 2015. 3 states had effective policy changes that occurred between 2001-2015)
import excel using "$data2\nme policy.xlsx", cellrange(A2:G53) firstrow clear
keep state fips exemp_relig exemp_pb
tempfile nme_policy_2014
save `nme_policy_2014'
clear
	
* Create one file with all vaccine related policy information

use "$data2\state_yr_obs00_15.dta", clear //dataset containing only state/fips/year obs for 2000-2015
rename year year12
merge m:1 fips using `tdap_mcv_hpv_policy' 
	ren _merge _merge1
merge 1:1 fips year12 using `other_ms_mandates' //NOTE: these are all policies coded to YEAR12
	ren _merge _merge2
drop if fips==.
drop _merge*

merge m:1 fips using `ccK_mandates' //these are state observations with year of implementation
	drop _merge
	
	
merge m:1 fips using `nme_policy_2014'
	ren _merge _merge1
	replace exemp_pb=0 if fips==48 & year12<=2002 //Texas added pb exemp in 2003
	replace exemp_pb=0 if fips==5 & year12<=2002 //Arkansas added pb exemp in 2003
	replace exemp_pb=1 if fips==35 & year<2013 //NM removed pb exemp in 2013
	
	
merge m:1 fips using `insure_policy'
	ren _merge _merge2
	gen imminsure_12yo = 0
	replace imminsure_12yo=1 if year12>imminsure_year //1 year-lag (ignoring month info)
	gen wc_12yo = 0
	replace wc_12yo=1 if year12>WC_year //again, 1 year-lag (ignoring month)
	
merge m:1 fips using `HPV_insure_policy'
	ren _merge _merge3
	gen HPVinsure_12yo = 0
	replace HPVinsure_12yo =1 if year12>HPVinsure_year & HPVinsure_year!=. //1 year-lag(ignoring month info), NOT turning on for all with ACA 

merge m:1 fips using `HPV_policy2'
	ren _merge _merge4
	gen HPVed_parent = 0
	replace HPVed_parent =1 if year12>HPVed_parent_yr & HPVed_parent_yr!=. //1 year-lag
	label var HPVed_parent "=1 if state has lagged effective HPV parent ed mandate"
	
	gen HPVed_stud = 0
	replace HPVed_stud =1 if year12>HPVed_stud_yr & HPVed_stud_yr!=. //1 year-lag
	label var HPVed_stud "=1 if state has lagged effective HPV student ed"
		
	gen HPVaware = 0
	replace HPVaware =1 if year12>HPVaware_yr & HPVaware_yr!=. //1 year-lag
	label var HPVaware "=1 if state has had an HPV awareness campaign, lagged 1 year "
	
	replace HPVpharm_yr = "2008" if HPVpharm_yr=="≤2008" //Note: The HPV pharmacist control is only known as of 2008, so NOT to be used as a control for time periods prior to 2008	
	destring HPVpharm_yr, replace
	gen HPVpharm = 0
	replace HPVpharm =1 if year12>HPVpharm_yr & HPVpharm_yr!=. //1 year-lag
	label var HPVpharm "=1 if state has lagged effective authority for pharmacist to admin HPV"
	
	drop _merge*
//create variables that capture number of years relative to implementation year
gen TDcont_year12 = Tdap_year12
	replace TDcont_year12 = TD_year12 if TD_year12<Tdap_year12 //recall: missing values take +infinity in logical statements 
gen m_Tdap = year12- Tdap_year12 + 1
gen m_MCV = year12 - MCV_year12 + 1 
gen m_TDcont = year12 - TDcont_year12 + 1
gen m_HPV = year12 - HPV_year12 + 1

//for MCV education, booster, and college policies, must look at contemporaneous effects 
destring MCV_boost_yr MCVed_yr MCVed_PS_yr MCV_PS_yr, replace
gen m_MCVboost = year12 - MCV_boost_yr + 1
gen m_MCVed = year12 - MCVed_yr + 1
gen m_MCVed_PS = year12 - MCVed_PS_yr + 1
gen m_MCV_PS = year12 - MCV_PS_yr + 1

gen td_10yrboostyr = td_yr if td_10yrboost==1
//for contemporaneous measures of CC and K mandates
global ccKmandates "hepB_K hepA_CC hepA_K hib_ varic_CC_K pcv_ flu_CC rota_ mumps_ meas_2 td_10yrboost"
foreach man of global ccKmandates{
gen m_`man'= year12 - `man'yr + 1
gen `man'mandate =0
replace `man'mandate = 1 if m_`man'>=1 & m_`man'!=.
}


	//Dummy vars for if there is an effective mandate
gen Tdap_mandate = 0 //variable for Tdap specific
replace Tdap_mandate = 1 if m_Tdap>=1 & m_Tdap!=.

gen TDcont_mandate = 0 //for TD-containing
replace TDcont_mandate = 1 if m_TDcont>=1 & m_TDcont!=.

gen MCV_mandate = 0
replace MCV_mandate=1 if m_MCV>=1 & m_MCV!=.

gen HPV_mandate= 0 
replace HPV_mandate=1 if m_HPV>=1 & m_HPV!=. 

gen MCV_boost = 0
replace MCV_boost = 1 if m_MCVboost>=1 & m_MCVboost!=.

gen MCVed_PS = 0
replace MCVed_PS = 1 if m_MCVed_PS>=1 & m_MCVed_PS!=.

gen MCVed = 0
replace MCVed = 1 if m_MCVed>=1 & m_MCVed!=.

gen MCV_waiver = 0
replace MCV_waiver = 1 if m_MCV_PS>=1 & MCV_waiver_any==1

gen MCV_PSmandate = 0
replace MCV_PSmandate = 1 if m_MCV_PS>=1 & MCV_PSmandate_any==1

	//create a var for any MS mandate
gen MSmandate1 = 0
replace MSmandate1=1 if (TDcont_mandate==1 | MCV_mandate==1| HPV_mandate==1)
label var MSmandate1 "=1 if effective TD, MCV, or HPV mandate (excludes catch-up vaccs)" 

gen MSmandate2 = MSmandate1
replace MSmandate2 = 1 if (Meas_newlybind==1 | Varic_newlybind==1 | HepB_newlybind==1 | HepA_newlybind==1)
label var MSmandate2 "=1 if there are any binding MS mandates" 

//create a var for any binding mandate on a catch-up vaccine
gen catchup_any=0
replace catchup_any=1 if (Meas_newlybind==1 | Varic_newlybind==1 | HepB_newlybind==1 | HepA_newlybind==1)

gen catchupXTDcont = catchup_any*TDcont_mandate
gen catchupXMCV = catchup_any*MCV_mandate
gen TDcontXMCV = TDcont_mandate*MCV_mandate
gen catchupXms = catchup_any*MSmandate1


* Event study dummy vars
global MS_vacc "Tdap TDcont MCV HPV"
foreach var of global MS_vacc{
	forvalue i=1/5{
	gen M_`var'_neg`i' = 0
	replace M_`var'_neg`i' = 1 if m_`var'==-`i'
	}
	
	
	forvalue i=0/9{
	gen M_`var'_`i' = 0
	replace M_`var'_`i' = 1 if m_`var'==`i'
	}
	
	gen M_`var'_gt7 = 0 
	replace M_`var'_gt7 =1 if m_`var'>7 & m_`var'!=.
	
	gen M_`var'_gte5 = 0 
	replace M_`var'_gte5 =1 if m_`var'>=5 & m_`var'!=.
	
	//create a policy dummy for m<-5
	gen M_`var'_ltneg5 = 0
	replace M_`var'_ltneg5 =1 if m_`var'<-5 & m_`var'!=.
	}

	
	
	save "$data\vaccpolicy_st_yr12.dta", replace
