/* **************************************************************************
	Name of file: 	policy_prep2_year12.do
	
	Author: 		Emily Lawler  - emily.lawler@uga.edu
										
	Project: 		Middle School Vaccination
	
				
	Last Edited:   06/2/2016 9:30 AM
	
	Files Used: Section 317 state funding 1995-2003, 2007-2013.xlsx, VFC policy 2001-2010.xlsx, medicaid_thresholds_2000_2015.dta,
	st_yr_cps.dta, BLS_st_yr.dta, cdc_diseases_surv.dta, NISteen08_15.dta, vaccpolicy_st_yr12.dta
					
	Files Created: vacc_analysisfile.dta
								
	NOTES:   
	1) Merges in final set of policy variables, state X's, and combines them NIS-Teen micro files
	2) Produces the final file to be used for main set of vaccination analyses (**policies coded as relevant to 12 year olds**) 
	*************************************************************************** */
	
	capture clear
	capture log close 
	capture clear matrix
	set more off 
	estimates clear
	

* +++++++++++++++++++++++++++++++++++
	* Secondary Globals - Dont change this! - 

global data     "$root/Data"
global NISdata  "$root/Data/NIS Teen"
global data2 	"$root/Data/Background"
global output   "$root/Output"
global tables   "$root/Output/Tables"
global figures  "$root/Output/Figures"
global dofiles  "$root/Do files"
global dofiles2 "$root/Do files/Background"
global logs 	"$root/Logs"
* +++++++++++++++++++++++++++++++++++
	
	*************************************
	//Section 317 funds only for 1995-2003, 2007-2013
	import excel using "$data2\Section 317 state funding 1995-2003, 2007-2013.xlsx", sheet("Stata ready") cellrange(A2:F819) firstrow clear
	drop state s317_DA s317_FA
	rename year year11
	tempfile s317_yr11
	save `s317_yr11'
	clear

	//VFC measures only for 2000-2010
	import excel using "$data2\VFC policy 2001-2010.xlsx", cellrange(A1:I562) firstrow clear
	rename universal vfc_uni
	rename universal_select vfc_unisel
	rename Other vfc_other
	drop State
	destring, replace
		replace vfc_only=0 if vfc_only==.
		replace vfc_underins = 0 if vfc_underins==.
		replace vfc_underins_select = 0 if vfc_underins_select==.
		replace vfc_uni = 0 if vfc_uni==.
		replace vfc_unisel = 0 if vfc_unisel==.
		replace vfc_other = 0 if vfc_other==.
	rename year year11
	tempfile vfc_yr11
	save `vfc_yr11'
	clear
		
	use "$data\medicaid_thresholds_2000_2015.dta", clear
	drop date state
	rename year year11
	tempfile mdcdthresh_yr11
	save `mdcdthresh_yr11'
	clear
	  
	use "$data2\st_yr_cps.dta", clear
	rename year year11
	tempfile cps_year11
	save `cps_year11'
	clear
	
	use "$data2\BLS_st_yr.dta", clear
	rename year year11
	tempfile bls_year11
	save `bls_year11'
	clear
	
	use "$data\cdc_diseases_surv_1996_2015.dta", clear
	gen pert_rate_yr11 = (pert/total_pop)*100
	gen menin_rate_yr11 = (menin/total_pop)*100
	rename year year11
	tempfile cdc_year11
	save `cdc_year11'
	clear
	
	use "$data\cdc_diseases_surv_1996_2015.dta", clear
	gen pert_rate_yr12 = (pert/total_pop)*100
	gen menin_rate_yr12 = (menin/total_pop)*100
	rename year year12
	tempfile cdc_year12
	save `cdc_year12'
	clear
	
	
	use "$data2\lawatlas_pharmlaws.dta", clear
	rename year year11
	tempfile pharmlaws11
	save `pharmlaws11'
	
	*************************************
	use "$data\NISteen08_15_raw.dta", replace
	
	//recode of variables
	
	//standardize marital status var across years
	gen married = 0
	replace married=1 if marital2==1
	replace married=1 if marital==3
	drop marital*
	
	//create dummies for mother's age group
	gen mom_agegrp_1 = (AGEGRP_M_I==1)
	label var mom_agegrp_1 "1= Mom <=34yo"
	gen mom_agegrp_2 = (AGEGRP_M_I==2)
	label var mom_agegrp_2 "1= Mom 35-44yo"
	gen mom_agegrp_3 = (AGEGRP_M_I==3)
	label var mom_agegrp_3 "1= Mom 45+yo"
	
	//create dummies for mother's education group
	gen mom_ed_1 = (EDUC1==1)
	label var mom_ed_1 "Less than HS"
	gen mom_ed_2 = (EDUC1==2)
	label var mom_ed_2 "HS (12yrs)"
	gen mom_ed_3 = (EDUC1==3)
	label var mom_ed_3 "Some college (>12 yrs)"
	gen mom_ed_4 = (EDUC1==4)
	label var mom_ed_4 "college grad"
	
	//create dummies for TEEN education group
	gen teen_ed_1 = (EDUC_TR==1)
	label var teen_ed_1 "6th-8th grade"
	gen teen_ed_2 = (EDUC_TR==2)
	label var teen_ed_2 "9th-12th grade"
	gen teen_ed_3 = (EDUC_TR==3)
	label var teen_ed_3 "HS grad/GED program"
	gen teen_ed_4 = (EDUC_TR==4)
	label var teen_ed_4 "Not in school/other"

	//rename variable for number of people in household
	rename C1R hh_num
	
	//create dummy variables for number of children under 18yo in hh
	gen child_lt18_1 = (childnm==1)
	label var child_lt18_1 "1= Only 1 child lt 18 in HH"
	gen child_lt18_2 = (childnm==2)
	label var child_lt18_2 "1= 2-3 children lt 18 in HH"
	gen child_lt18_3 = (childnm==3)
	label var child_lt18_3 "1= 4+ children lt 18 in HH"
	
	//create race/ethnicity dummies
	gen ethcat_1 = (raceethk==1)
	label var ethcat_1 "1=Hispanic"
	gen ethcat_2 = (raceethk==2)
	label var ethcat_2 "1=non-Hispanic, white"
	gen ethcat_3 = (raceethk==3)
	label var ethcat_3 "1=non-Hispanic, black"
	gen ethcat_4 = (raceethk==4)
	label var ethcat_4 "1=non-Hispanic other + multiple race"
	
	recode sex (1=0) (2=1), gen(female)
	label var female "1=child is a female, 0=male"
	
	//create vars for public vs. private health ins
	//gen var for if individual has any non-missing health insurance var
	gen ins_answer =.
	replace ins_answer=1 if (TIS_INS_1==1 | TIS_INS_1==2 | TIS_INS_11==1 | TIS_INS_11==2 | TIS_INS_2==1 | TIS_INS_2==2 | TIS_INS_3==1 | TIS_INS_3==2 | TIS_INS_3A==1 | TIS_INS_3A==2 | TIS_INS_4==1 | TIS_INS_4==2 | TIS_INS_5==1 | TIS_INS_5==2 | TIS_INS_4_5==1 | TIS_INS_4_5==2 | TIS_INS_6==1 | TIS_INS_6==2 )
	

	gen ins_private = .
	replace ins_private=1 if TIS_INS_1==1
	replace ins_private=0 if TIS_INS_1==2
	
	gen ins_caid=.
	replace ins_caid=1 if (TIS_INS_2==1|TIS_INS_3==1|TIS_INS_3A==1)
	replace ins_caid=0 if TIS_INS_2==2 & TIS_INS_3==2
	replace ins_caid=0 if TIS_INS_3A==2
	
	gen ins_public= . 
	replace ins_public=1 if (TIS_INS_2==1|TIS_INS_3==1|TIS_INS_3A==1|TIS_INS_4==1| TIS_INS_5==1| TIS_INS_4_5==1)
	replace ins_public=0 if ins_public==. & ins_caid==0
	replace ins_public = 0 if ins_public==. & TIS_INS_4==2 & TIS_INS_5==2
	replace ins_public = 0 if ins_public==. & TIS_INS_4_5==2
	
	gen ins_other = .
		replace ins_other = 1 if TIS_INS_6==1
		replace ins_other = 0 if TIS_INS_6==2
		
	//create dummies for facility type of teen's providers
	gen facility_1 = (facility==1)
	label var facility_1 "1= all public"
	gen facility_2 = (facility==2)
	label var facility_2 "1= all hospital"
	gen facility_3 = (facility==3)
	label var facility_3 "1= all private"
	gen facility_4 = (facility==4)
	label var facility_4 "1= all STD/teen/school clinics"
	gen facility_5 = (facility==5)
	label var facility_5 "1= mixed"
	
	//change facility dummies to missing if facility type is missing or unknown (facility==6)
	forvalues i=1/5{
	replace facility_`i' = . if (facility==6|facility==.)
	}
	
	//create a dummy for having a well-child check-up between different age ranges
	//note, CKUP_11_12 is missing for some observations where CKUP_AGE== 11, 12
	rename CKUP_11_12 CKUP_11_12_nis
	recode CKUP_11_12_nis (2=0) (1=1) (77 99 = .),gen (ckup_11_12)
	replace ckup_11_12=1 if (CKUP_AGE==11| CKUP_AGE==12)
	replace ckup_11_12=0 if CKUP_AGE<=10
	
	//collapse income categories
	recode INCQ298A (3 4=1) (5 6 =2) (7 8=3) (9 10=4) (11=5) (12=6) (13=7) (14=8) (77 99=.), gen(income_cat1)
	label define income_cat1 1 "$0-10K" 2 "10-20K" 3 "20-30K" 4 "30-40K" 5 "40-50K" 6 "50-60K" 7"60-75K" 8 "75K+"
	label values income_cat1 income_cat1
	
	recode INCQ298A (3 4 5 6 =1) (7 8 9 10=2) (11 12=3) (13=4) (14=5) (77 99 =.), gen(income_cat2)
	label define income_cat2 1 "0-20K" 2 "20-40K" 3 "40-60K" 4 "60-75K" 5 "75K+"
	label values income_cat2 income_cat2
	
	//create a dummy for having ever received flu shot in 3 yrs prior to 13
	gen flu_10_13 = P_N13FLU
	replace flu_10_13 = 1 if P_N13FLU>1 & P_N13FLU!=.
	
	//create dummies for provider VFC order status
	gen VFC_order_1 = (VFC_ORDER==1)
	label var VFC_order_1 "1=all providers VFC order"
	gen VFC_order_2 = (VFC_ORDER==2)
	label var VFC_order_2 "1=some providers VFC order"
	gen VFC_order_3 = (VFC_ORDER==3)
	label var VFC_order_3 "1=no providers VFC order"
	
	//change VFC_order dummies to missing if VFC_ORDER status is missing or unknown (VFC_ORDER==4)
	forvalues i=1/3{
	replace VFC_order_`i' = . if (VFC_ORDER==4|VFC_ORDER==.)
	}
	
	label var noschoolr "# days school missed" //due to illness or injury, in last 12 months
	label define nosch 0 "0 days" 1 "1 day" 2 "2 days" 3 "3 days" 4 "4 days" 5 "5 days" 6 "6 to 9 days" 7 "10 to 19 days" 8 "20 to 29 days" 9 "30+ days" 96 "Did not go to school" 77 "DK" 99 "Refused"
	label values noschoolr nosch
	
	recode noschoolr (0 = 0) (1 2 3 4 5 = 1) (6=2) (7=3) (8=4) (9=5) (96 77 99 = .), gen(noschool_grpd)
	label define nosch2 0 "0 days" 1 "1 to 5 days" 2 "6 to 9 days" 3 "10 to 19 days" 4 "20 to 29 days" 5 "30+ days"
	label values noschool_grpd nosch2	
	
		recode HPVI_KNOW (1=1) (2=0) (77 99 =.), gen(hpv_vaccknow)
	recode HPVI_HEARD (1=1) (2=0) ( 77 99=.), gen(hpv_heard)
	recode HPVI_RECOM (1=1) (2=0) (77 99=.), gen(hpv_rec)
	
	//note: Vaccknow and heard vars are only available for observations from 2008-2011
		//also: these vars are not measured as "at age 13," so probably more correct to also include age dummies
	label var hpv_vaccknow "Know HPV vacc"
	label var hpv_heard "Heard of HPV"
	label var hpv_rec "Rec'd HPV rec"
	
	//replace "have heard of hpv"=1 if "know about hpv vacc"=1
	replace hpv_heard=1 if hpv_vaccknow==1
	
	rename state fips

	//create var for 3+ hpv
	gen hpv3 = .
	replace hpv3 = 1 if P_NUMHPV>=3 & P_NUMHPV!=.
	replace hpv3 = 0 if P_NUMHPV<3 & P_NUMHPV!=.
	label var hpv3 "3+ HPV"
	
	gen hpv3_13 = .
	replace hpv3_13 = 1 if P_N13HPV>=3 & P_N13HPV!=.
	replace hpv3_13 = 0 if P_N13HPV<3 & P_N13HPV!=.
	label var hpv3_13 "3+ HPV, 13yo"
	
	gen hpv2_13 = .
	replace hpv2_13 = 1 if P_N13HPV>=2 & P_N13HPV!=.
	replace hpv2_13 = 0 if P_N13HPV<2 & P_N13HPV!=.
	label var hpv2_13 "2+ HPV, 13yo"
	
	gen hpv1_13=  P_U13HPV
	label var hpv1_13 "1+ HPV, 13yo"
	
	//create a dummy var for a TD booster between age 10 and 13
	gen TD_10_13 = P_N13TDP_POST10 //use var that counts number of boosters between age 10 and 13
	replace TD_10_13=1 if P_N13TDP_POST10>=1 & P_N13TDP_POST10!=.
	label var TD_10_13 "TD booster (10-13yo)"
	
	//var for tdap specific
	label var P_U13TDAP "Tdap booster, 10-13yo"
	
	label var P_U13TD "TD UTD, 13yo"
	label var P_U13MEN "1+ MENIN, 13yo"
	
	global LHS "TD_10_13 P_U13TDAP P_U13MEN ckup_11_12"
	
	label var female "female"
	
	label var ckup_11_12 "11-12yo ckup"
	
	gen year13 = year-age +13
	gen year12 = year-age + 12
	gen year11 = year-age +11
	

drop if fips==66|fips==72|fips==78

save "$data\NISteen08_15.dta", replace

*********************************

use "$data\NISteen08_15.dta", replace


* Merge in policy data
merge m:1 fips year12 using "$data\vaccpolicy_st_yr12.dta", keep(master matched)
		ren _merge _merge1
* Merge in state-year controls (merging to year 11)

merge m:1 fips year11 using `cps_year11', keep(master matched)
	ren _merge _merge2
merge m:1 fips year11 using `bls_year11', keep(master matched)
	ren _merge _merge3
merge m:1 fips year11 using `cdc_year11', keep(master matched) keepusing(pert_rate_yr11 menin_rate_yr11)
	ren _merge _merge4
merge m:1 fips year12 using `cdc_year12', keep(master matched) keepusing(pert_rate_yr12 menin_rate_yr12)
	ren _merge _merge5
merge m:1 fips year11 using `mdcdthresh_yr11', keep(master matched)
	ren _merge _merge6
merge m:1 fips year11 using `s317_yr11', keep(master matched)
	ren _merge _merge7
merge m:1 fips year11 using `vfc_yr11', keep(master matched)
	ren _merge _merge8
merge m:1 fips year11 using `pharmlaws11', keep(master matched)
	
drop _merge*


//cleaning up/combining pharmacist vacc authority law variables
	gen pharmlaw_miss = 0
	replace pharmlaw_miss = 1 if (rx_pert==.| rx_mcv==.| rx_hpv==.| ga_pert==.| ga_mcv==.| ga_hpv==.| ps_pert==.| ps_mcv==.| ps_hpv==.)
	
	global vars "rx_pert rx_mcv rx_hpv ga_pert ga_mcv ga_hpv ps_pert ps_mcv ps_hpv"
	foreach var of global vars{
	replace `var' = 0 if `var'==.
	} 
	
	gen gaOrx = ga_pert
		replace gaOrx=1 if rx_pert==1
	
	label var gaOrx "Pharmacist RX or general authority for pertussis, 11+ yr olds"
	
	gen garxXmandate = gaOrx * TDcont_mandate


save "$data\vacc_analysisfile.dta", replace


