
	/* **************************************************************************
	Name of file: 	vaccination_analysis.do
	
	Author: 		Emily Lawler  - emily.lawler@uga.edu
										
	Project: 		Middle School Vaccination
	
	Introduction: 
				
				
	Last Edited:   01/15/2018 9:30 AM
	
	Files Used: vacc_analysisfile.dta
					
	Files Created: 
								
	NOTES:   
	1) 
	*************************************************************************** */
	
	capture clear
	capture log close 
	capture clear matrix
	set more off 
	estimates clear
	

* +++++++++++++++++++++++++++++++++++
	* Secondary Globals - Dont change this! - 
global data     "$root/Data"
global NISdata  "$root/Data/NIS Teen"
global data2 	"$root/Data/Background"
global output   "$root/Output"
global tables   "$root/Output/Tables"
global figures  "$root/Output/Figures"
global dofiles  "$root/Do files"
global dofiles2 "$root/Do files/Background"
global logs 	"$root/Logs"
* +++++++++++++++++++++++++++++++++++


 use "$data\vacc_analysisfile.dta", clear

	gen trend = year13-2003
	gen trend_sq = trend*trend
	gen trend_cu = trend*trend*trend
	
	xi i.fips*trend i.fips*trend_sq i.fips*trend_cu 
	
	global linear "_IfipXtren_*"
	global quadratic "_IfipXtren_* _IfipXtrena*"
	global cubic "_IfipXtren_* _IfipXtrena* _IfipXtrenb*"
	
	global MS_vacc "Tdap TDcont MCV HPV"
	
	//event study with -1 omitted
	foreach var of global MS_vacc{
	global es1_`var' "M_`var'_ltneg5 M_`var'_neg5 M_`var'_neg4 M_`var'_neg3 M_`var'_neg2 M_`var'_0 M_`var'_1 M_`var'_2 M_`var'_3 M_`var'_4 M_`var'_gte5" /*M_`var'_5 M_`var'_6 M_`var'_7 M_`var'_gt7*/
	}
	
	//event study with -1 and -2 omitted
	foreach var of global MS_vacc{/* M_`var'_neg1*/
	global es2_`var' "M_`var'_ltneg5 M_`var'_neg5 M_`var'_neg4 M_`var'_neg3 M_`var'_0 M_`var'_1 M_`var'_2 M_`var'_3 M_`var'_4 M_`var'_gte5" /*M_`var'_5 M_`var'_6 M_`var'_7 M_`var'_gt7*/
	}
	
	
	global individ_controls "female child_lt18_* mom_ed_* married mom_agegrp_* ethcat_*"
	
	
	global VaccMandates "TDcont_mandate MCV_mandate HPV_mandate Meas_newlybind Varic_newlybind Varic_new2dose HepB_newlybind HepA_newlybind" 
	global Vacc_controls "exemp_pb wc_12yo imminsure_12yo MCV_boost MCVed_PS MCVed MCV_waiver MCV_PSmandate HPVinsure_12yo HPVed_parent HPVed_stud HPVaware hepB_Kmandate hepA_CCmandate hepA_Kmandate hib_mandate varic_CC_Kmandate pcv_mandate flu_CCmandate rota_mandate mumps_mandate meas_2mandate"	//Also:   , only to be used in analysis 2009 forward
	global styr "pert_rate_yr11 menin_rate_yr11 mdcd_upperlmt styr_perblack styr_perhispan styr_perother_eth styr_perfemale styr_perlt21 styr_per21_64 styr_HSrate styr_uni4rate styr_povrate unemp_rate"
	global hpv_lhs "hpv_rec hpv_vaccknow hpv_heard hpv1_13 hpv2_13 hpv3_13"
	
	//For baseline regression:use dual-frame provider weights for 2011-2014 
		*(note: cell phones added in 2011, & that is the only year with both a landline only & dual frame weight available)
	replace provwt= provwt_d if provwt==.
	replace rddwt=rddwt_d if rddwt==.
	
	label var P_U13HEPA "UTD HepA, 13yo"
	label var P_U13HEPB "UTD HepB, 13yo"
	label var P_U13MCV "UTD Meas, 13yo"
	label var P_U13VRC "UTD 1+ Varic, 13yo"
	label var P_U13VRC2 "UTD 2+ Varic, 13yo"
	label var P_N13FLU "# Flu vacc in 3 yrs prior, 13yo"
	label var flu_10_13 "Any flu vacc, 10-13 yo"
	
	//create outcome variables for jointly having tdap and other vaccines
	gen TDAPyMEN = P_U13TDAP
		replace TDAPyMEN = 0 if P_U13MEN==0
	gen TDAPyHPV1 = P_U13TDAP
		replace TDAPyHPV1 = 0 if hpv1_13==0
	gen TDAPyHPV3 = P_U13TDAP
		replace TDAPyHPV3 = 0 if hpv3_13==0
	gen TDAPyflu = 	P_U13TDAP
		replace TDAPyflu =0 if flu_10_13==0
		
	gen TDAPyMENyHPV1 = TDAPyMEN
		replace TDAPyMENyHPV1=0 if hpv1_13==0
	gen TDAPyMENyHPV3 = TDAPyMEN
		replace TDAPyMENyHPV3=0 if hpv3_13==0
		
	gen TDAPyMENyHPV1yFlu = TDAPyMENyHPV1
		replace TDAPyMENyHPV1yFlu = 0 if flu_10_13==0
		
	//create var that captures role of acip recommendation: outcome is receipt of vacc when acip recommended
	
	gen MCVyRec = P_U13MEN 
		replace MCVyRec = 0 if year12<2005
	
	gen HPV1yRec = hpv1_13
		replace HPV1yRec = 0 if year12<2006 & female==1
		replace HPV1yRec = 0 if year12<2011 & female==0
	
	gen HPV3yRec = hpv3_13
		replace HPV3yRec = 0 if year12<2006 & female==1
		replace HPV3yRec = 0 if year12<2011 & female==0
	
	gen FluyRec = flu_10_13
		replace FluyRec= 0 if year12<2010
		
	//create a treatment variable that captures ACIP recommendation and presence of TD cont mandate		
	gen TDcontmXacipMCV = TDcont_mandate
		replace TDcontmXacipMCV = 0 if year12<2005
	
	gen TDcontmXacipHPV = TDcont_mandate
		replace TDcontmXacipHPV = 0 if year12<2006 & female==1
		replace TDcontmXacipHPV = 0 if year12<2011 & female==0
	
	gen TDcontmXacipFlu = TDcont_mandate
		replace TDcontmXacipFlu = 0 if year12<2010

	
	gen flu_any3yr = P_NUMFLU
		replace flu_any3yr = 1 if P_NUMFLU>=1 & P_NUMFLU!=.
		
	//recode pdat2 (. 2 =0) (1=1)
	
	gen hpv_tag = 0
	replace hpv_tag=1 if female==1 & year12>=2006
	replace hpv_tag=1 if female==0 & year12>=2010
	
	global hpvLHS "hpv1_13 hpv2_13 hpv3_13"
	 global LHS1 "P_U13TDAP P_U13MEN"
	******************************************************************
	* First, specifications including 2014 and 2015 sample (as robustness)
		
	/*APPENDIX TABLE 10*/ 
	
	estimates clear
	foreach var of global LHS1{
	eststo: reg `var' $VaccMandates $Vacc_controls  $individ_controls $styr i.age i.fips i.year12 [aw=provwt], vce(cluster fips)
	estadd ysumm
	estadd local linear ""
	estadd local quad ""
	
	eststo: reg `var' $VaccMandates $Vacc_controls  $individ_controls $styr i.age i.fips i.year12  $linear [aw=provwt], vce(cluster fips)
	estadd ysumm
	estadd local linear "X"
	estadd local quad ""
	}

	//main hpv result
	foreach var of global hpvLHS_2{
	eststo: reg `var'  $VaccMandates $Vacc_controls  $individ_controls $styr  i.age i.fips i.year12 [aw=provwt] if  hpv_tag==1, vce(cluster fips)
	estadd ysumm
	estadd local linear ""
	estadd local quad ""

	eststo: reg `var'  $VaccMandates $Vacc_controls $individ_controls $styr  i.age i.fips i.year12  $linear [aw=provwt] if hpv_tag==1, vce(cluster fips)
	estadd ysumm
	estadd local linear "X"
	estadd local quad ""
	
	}
		
	esttab est* using "$output\vaccresults01152018.rtf", append keep(TDcont_mandate) /*
	*/ se label star(* 0.10 ** 0.05 *** 0.01) stats(N r2 ymean linear quad, label("N" "R-Squared" "Mean of Dependent" "linear trend" "quadratic trend")) title(Robustness: USING NIS-TEEN 2008-2015) /*
	*/ note("All columns are weighted, have age, state and birth cohort fixed effects. SE are clustered at the state level.")
	
	drop if year>=2014 //DROPPING SURVEY YEARS 2014 and 2015
	****************************************************************
	/* APPENDIX TABLE 1:Descriptive Stats */
	
	quietly{
	reg P_U13TDAP $es2_TDcont $es2_MCV $es2_HPV Meas_newlybind Varic_newlybind HepB_newlybind HepA_newlybind $Vacc_controls $individ_controls $styr i.fips i.age i.year12 [aw=provwt], vce(cluster fips)
	}
	//full sample
	sum P_U13TDAP P_U13MEN  flu_10_13 female ethcat_*  ckup_11_12 child_lt18_* mom_ed_* married mom_agegrp_*  [aw=provwt] if e(sample)==1
	sum  hpv1_13 hpv3_13 [aw=provwt] if hpv_tag==1 & e(sample)==1
	//by state mandate status
	replace tdap_any=0 if tdap_yr==2014
	sum P_U13TDAP P_U13MEN flu_10_13 female ethcat_*  ckup_11_12 child_lt18_* mom_ed_* married mom_agegrp_*  [aw=provwt] if (tdap_any==1|td_MS==1) & e(sample)==1
		sum hpv1_13 hpv3_13  [aw=provwt] if (tdap_any==1|td_MS==1) & hpv_tag==1 & e(sample)==1

	sum P_U13TDAP P_U13MEN flu_10_13 female ethcat_*  ckup_11_12 child_lt18_* mom_ed_* married mom_agegrp_*  [aw=provwt] if (tdap_any==0& td_MS==0) & e(sample)==1
		sum hpv1_13 hpv3_13  [aw=provwt] if (tdap_any==0 & td_MS==0) & hpv_tag==1 & e(sample)==1
		
	*****************************************************
	 
	/*FIGURE 4: Event Study Estimates*/
	

	estimates clear
	eststo: reg P_U13TDAP $es1_TDcont $es1_MCV $es1_HPV Meas_newlybind Varic_newlybind HepB_newlybind HepA_newlybind $Vacc_controls $individ_controls $styr i.fips i.age i.year12 [aw=provwt], vce(cluster fips)
	estadd ysumm
	estadd local linear ""
	estadd local yr ""
	
	esttab est* using "$output\vaccresults01152018.rtf", append wide keep($es1_TDcont) /*
	*/ se label star(* 0.10 ** 0.05 *** 0.01) stats(yr N r2 ymean linear, label("year13>=2007" "Observations" "R-Squared" "Mean of Dependent" "linear trend")) title(Effects of mandates on receipt of age-recommended vaccines) /*
	*/ note("All columns are weighted, have age, state and birth cohort fixed effects. SE are clustered at the state level.")
	

	***************************
	* Standard DD specifications 
	tab year12, gen(year12_)
	
	estimates clear
	foreach var of global LHS1{
	eststo: reg `var' $VaccMandates $Vacc_controls  $individ_controls $styr i.age i.fips year12_2-year12_10 [aw=provwt], vce(cluster fips)
	estadd ysumm
	estadd local linear ""
	estadd local quad ""
	
	eststo: reg `var' $VaccMandates $Vacc_controls  $individ_controls $styr i.age i.fips year12_2-year12_10  $linear [aw=provwt], vce(cluster fips)
	estadd ysumm
	estadd local linear "X"
	estadd local quad ""
	
	}
	
	/*TABLE 1, Vaccination Outcomes*/ 
	esttab est1 est2 using "$output\vaccresults01152018.rtf", append keep(TDcont_mandate) /*
	*/ se label star(* 0.10 ** 0.05 *** 0.01) stats(N r2 ymean linear quad, label("N" "R-Squared" "Mean of Dependent" "linear trend" "quadratic trend")) title(Effects of mandates on receipt of age-recommended vaccines) /*
	*/ note("All columns are weighted, have age, state and birth cohort fixed effects. SE are clustered at the state level.")
	

	
	//main hpv result
	
	foreach var of global hpvLHS{
	eststo: reg `var'  $VaccMandates $Vacc_controls  $individ_controls $styr  i.age i.fips year12_2-year12_10 [aw=provwt] if  hpv_tag==1, vce(cluster fips)
	estadd ysumm
	estadd local linear ""
	estadd local quad ""

	eststo: reg `var'  $VaccMandates $Vacc_controls $individ_controls $styr  i.age i.fips year12_2-year12_10 $linear [aw=provwt] if hpv_tag==1, vce(cluster fips)
	estadd ysumm
	estadd local linear "X"
	estadd local quad ""
	}
	
	eststo: reg flu_10_13  $VaccMandates $Vacc_controls  $individ_controls $styr i.age i.fips i.year12  [aw=provwt], vce(cluster fips)
	estadd ysumm
	estadd local linear ""
		
	eststo: reg flu_10_13  $VaccMandates $Vacc_controls  $individ_controls $styr i.age i.fips i.year12  $linear [aw=provwt], vce(cluster fips)
	estadd ysumm
	estadd local linear "X"
	
	/*TABLE 3: Spillover effects to other ACIP-recommended Vaccines*/
	esttab est3 est4 est5 est6 est9 est10 est11 est12 using "$output\vaccresults01152018.rtf", append keep(TDcont_mandate) /*
	*/ se label star(* 0.10 ** 0.05 *** 0.01) stats(N r2 ymean linear quad, label("N" "R-Squared" "Mean of Dependent" "linear trend" "quadratic trend")) title(Spillover Effects to Other ACIP-Recommended Vaccines) /*
	*/ note("All columns are weighted, have age, state and birth cohort fixed effects. SE are clustered at the state level.")
	
	/*EXTRA TABLE: Similar Spillover Results for 2 dose of HPV vaccine series*/ 
	esttab est7 est8 using "$output\vaccresults01152018.rtf", append keep(TDcont_mandate) /*
	*/ se label star(* 0.10 ** 0.05 *** 0.01) stats(N r2 ymean linear quad, label("N" "R-Squared" "Mean of Dependent" "linear trend" "quadratic trend")) title(Spillover Effects to Other ACIP-Recommended Vaccines) /*
	*/ note("All columns are weighted, have age, state and birth cohort fixed effects. SE are clustered at the state level.")
	

	
	
	 
		
	
	*******************************************
	
	
	global hetero_LHS "P_U13TDAP P_U13MEN"
		global hpvLHS_2 "hpv1_13 hpv3_13"
	
	/*Table 4: Heterogeneity in Vaccination Effects*/
	
	//Full Sample
	estimates clear
	foreach var of global hetero_LHS{
	eststo: reg `var' $VaccMandates $Vacc_controls  $individ_controls $styr i.age i.fips i.year12 $linear [aw=provwt], vce(cluster fips)
	estadd ysumm
	estadd local yr "`lab`i''"
	}
	
	foreach var of global hpvLHS_2{
	eststo: reg `var' $VaccMandates $Vacc_controls  $individ_controls $styr i.age i.fips i.year12 $linear [aw=provwt] if hpv_tag==1 , vce(cluster fips)
	estadd ysumm
	estadd local yr "`lab`i''"
	}
	esttab est* using "$output\vaccresults01152018.rtf", append keep(TDcont_mandate) /*
	*/ se label star(* 0.10 ** 0.05 *** 0.01) stats(yr N r2 ymean, label("Sample" "N" "R-Squared" "Mean of Dependent")) title(Effects of mandates, heterogeneity analysis: full sample) /*
	*/ note("All columns are weighted, have age, state and birth cohort fixed effects. SE are clustered at the state level.")
	
	
	//females 
	
	estimates clear
	foreach var of global hetero_LHS{
	eststo: reg `var' $VaccMandates $Vacc_controls  $individ_controls $styr i.age i.fips i.year12 $linear [aw=provwt] if female==1, vce(cluster fips)
	estadd ysumm
	estadd local yr "`lab`i''"
	}
	foreach var of global hpvLHS_2{
	eststo: reg `var' $VaccMandates $Vacc_controls  $individ_controls $styr i.age i.fips i.year12 $linear [aw=provwt] if female==1  & hpv_tag==1 , vce(cluster fips)
	estadd ysumm
	estadd local yr "`lab`i''"
	}
	
	esttab est* using "$output\vaccresults01152018.rtf", append keep(TDcont_mandate) /*
	*/ se label star(* 0.10 ** 0.05 *** 0.01) stats(yr N r2 ymean, label("Sample" "N" "R-Squared" "Mean of Dependent")) title(Effects of mandates, heterogeneity analysis: females only) /*
	*/ note("All columns are weighted, have age, state and birth cohort fixed effects. SE are clustered at the state level.")
	
	//males
	
	
	estimates clear
	foreach var of global hetero_LHS{
	eststo: reg `var' $VaccMandates $Vacc_controls  $individ_controls $styr i.age i.fips i.year12 $linear [aw=provwt] if female==0 , vce(cluster fips)
	estadd ysumm
	estadd local yr "`lab`i''"
	}
	foreach var of global hpvLHS_2{
	eststo: reg `var' $VaccMandates $Vacc_controls  $individ_controls $styr i.age i.fips i.year12 $linear [aw=provwt] if female==0 & hpv_tag==1 , vce(cluster fips)
	estadd ysumm
	estadd local yr "`lab`i''"
	}
	esttab est* using "$output\vaccresults01152018.rtf", append keep(TDcont_mandate) /*
	*/ se label star(* 0.10 ** 0.05 *** 0.01) stats(yr N r2 ymean, label("Sample" "N" "R-Squared" "Mean of Dependent")) title(Effects of mandates, heterogeneity analysis: males only) /*
	*/ note("All columns are weighted, have age, state and birth cohort fixed effects. SE are clustered at the state level.")
	
	
	
	//whites
	estimates clear
	foreach var of global hetero_LHS{
	eststo: reg `var' $VaccMandates $Vacc_controls  $individ_controls $styr i.age i.fips i.year12 $linear [aw=provwt] if ethcat_2==1 , vce(cluster fips)
	estadd ysumm
	estadd local yr "`lab`i''"
	}
	foreach var of global hpvLHS_2{
	eststo: reg `var' $VaccMandates $Vacc_controls  $individ_controls $styr i.age i.fips i.year12 $linear [aw=provwt] if ethcat_2==1  & hpv_tag==1 , vce(cluster fips)
	estadd ysumm
	estadd local yr "`lab`i''"
	}
	esttab est* using "$output\vaccresults01152018.rtf", append keep(TDcont_mandate) /*
	*/ se label star(* 0.10 ** 0.05 *** 0.01) stats(yr N r2 ymean, label("Sample" "N" "R-Squared" "Mean of Dependent")) title(Effects of mandates, heterogeneity analysis: whites) /*
	*/ note("All columns are weighted, have age, state and birth cohort fixed effects. SE are clustered at the state level.")
	
	
	
	//black
	estimates clear
	foreach var of global hetero_LHS{
	eststo: reg `var' $VaccMandates $Vacc_controls  $individ_controls $styr i.age i.fips i.year12 $linear [aw=provwt] if ethcat_3==1 , vce(cluster fips)
	estadd ysumm
	estadd local yr "`lab`i''"
	}
	foreach var of global hpvLHS_2{
	eststo: reg `var' $VaccMandates $Vacc_controls  $individ_controls $styr i.age i.fips i.year12 $linear [aw=provwt] if ethcat_3==1 & hpv_tag==1 , vce(cluster fips)
	estadd ysumm
	estadd local yr "`lab`i''"
	}
	esttab est* using "$output\vaccresults01152018.rtf", append keep(TDcont_mandate) /*
	*/ se label star(* 0.10 ** 0.05 *** 0.01) stats(yr N r2 ymean, label("Sample" "N" "R-Squared" "Mean of Dependent")) title(Effects of mandates, heterogeneity analysis: blacks) /*
	*/ note("All columns are weighted, have age, state and birth cohort fixed effects. SE are clustered at the state level.")
	
	
	
	//hispanic
	estimates clear
	foreach var of global hetero_LHS{
	eststo: reg `var' $VaccMandates $Vacc_controls  $individ_controls $styr i.age i.fips i.year12 $linear [aw=provwt] if ethcat_1==1 , vce(cluster fips)
	estadd ysumm
	estadd local yr "`lab`i''"
	}
	foreach var of global hpvLHS_2{
	eststo: reg `var' $VaccMandates $Vacc_controls  $individ_controls $styr i.age i.fips i.year12 $linear [aw=provwt] if ethcat_1==1 & hpv_tag==1 , vce(cluster fips)
	estadd ysumm
	estadd local yr "`lab`i''"
	}
	esttab est* using "$output\vaccresults01152018.rtf", append keep(TDcont_mandate) /*
	*/ se label star(* 0.10 ** 0.05 *** 0.01) stats(yr N r2 ymean, label("Sample" "N" "R-Squared" "Mean of Dependent")) title(Effects of mandates, heterogeneity analysis: hispanic) /*
	*/ note("All columns are weighted, have age, state and birth cohort fixed effects. SE are clustered at the state level.")
	

	//mom ed: completed college
	sum  P_U13TDAP if mom_ed_4==1 & Tdap_mandate==0 [aw=provwt] 
	sum  P_U13TDAP if (mom_ed_1==1|mom_ed_2==1) & Tdap_mandate==0 [aw=provwt] 
	

	estimates clear
	foreach var of global hetero_LHS{
	eststo: reg `var' $VaccMandates $Vacc_controls  $individ_controls $styr i.age i.fips i.year12 $linear [aw=provwt] if mom_ed_4==1 , vce(cluster fips)
	estadd ysumm
	estadd local yr "`lab`i''"
	}
	foreach var of global hpvLHS_2{
	eststo: reg `var' $VaccMandates $Vacc_controls  $individ_controls $styr i.age i.fips i.year12 $linear [aw=provwt] if mom_ed_4==1  & hpv_tag==1 , vce(cluster fips)
	estadd ysumm
	estadd local yr "`lab`i''"
	}
	esttab est* using "$output\vaccresults01152018.rtf", append keep(TDcont_mandate) /*
	*/ se label star(* 0.10 ** 0.05 *** 0.01) stats(yr N r2 ymean, label("Sample" "N" "R-Squared" "Mean of Dependent")) title(Effects of mandates, heterogeneity analysis: mom is college grad) /*
	*/ note("All columns are weighted, have age, state and birth cohort fixed effects. SE are clustered at the state level.")
	
	
	
	//Mom ed of <BA
	estimates clear
	foreach var of global hetero_LHS{
	eststo: reg `var' $VaccMandates $Vacc_controls  $individ_controls $styr i.age i.fips i.year12 $linear [aw=provwt] if (mom_ed_1==1|mom_ed_2==1|mom_ed_3==1), vce(cluster fips)
	estadd ysumm
	estadd local yr "`lab`i''"
	}
	foreach var of global hpvLHS_2{
	eststo: reg `var' $VaccMandates $Vacc_controls  $individ_controls $styr i.age i.fips i.year12 $linear [aw=provwt] if (mom_ed_1==1|mom_ed_2==1|mom_ed_3==1) & hpv_tag==1 , vce(cluster fips)
	estadd ysumm
	estadd local yr "`lab`i''"
	}
	esttab est* using "$output\vaccresults01152018.rtf", append keep(TDcont_mandate) /*
	*/ se label star(* 0.10 ** 0.05 *** 0.01) stats(yr N r2 ymean, label("Sample" "N" "R-Squared" "Mean of Dependent")) title(Effects of mandates, heterogeneity analysis: mom has some college or less) /*
	*/ note("All columns are weighted, have age, state and birth cohort fixed effects. SE are clustered at the state level.")
	
	

	/*TABLE 5: Spillover Mechanisms*/ 
	
	local t5_samp1 "female==1 & year13>=2007  & age==13 & hpv_heard!=."
	local t5_samp2 "female==1 & year13>=2007  & age==13 & hpv_vaccknow!=."
	local t5_samp3 "hpv_tag==1 & age==13 & hpv_rec!=."
	local t5_samp4 "age==13 & ckup_11_12!=."
	
	local t5_samp_b1 ""
	
	local lhs1 "hpv_heard"
	local lhs2 "hpv_vaccknow"
	local lhs3 "hpv_rec"
	local lhs4 "ckup_11_12"
	
	
	estimates clear
	forvalues i=1/4{
	
	eststo: reg `lhs`i'' $VaccMandates $Vacc_controls  $individ_controls $styr i.age i.fips i.year12 [aw=rddwt] if `t5_samp`i'' &  P_U13TDAP!=., vce(cluster fips)
	estadd ysumm
	estadd local linear ""
	estadd local samp "`t5_samp`i'' `t5_samp_b`j''"
	
	eststo: reg `lhs`i'' $VaccMandates $Vacc_controls  $individ_controls $styr i.age i.fips i.year12  $linear [aw=rddwt] if `t5_samp`i'' &  P_U13TDAP!=., vce(cluster fips)
	estadd ysumm
	estadd local linear "X"
	estadd local samp "`t5_samp`i'' `t5_samp_b`j''"	
	}
	esttab est* using "$output\vaccresults01152018.rtf", append keep(TDcont_mandate) /*
	*/ se label star(* 0.10 ** 0.05 *** 0.01) stats(N r2 ymean linear samp, label("N" "R-Squared" "Mean of Dependent" "linear trend" "Sample:")) title(Spillover Mechanisms) /*
	*/ note("All columns are weighted, have age, state and birth cohort fixed effects. SE are clustered at the state level.")
	
	 
	
	************************************************************
	*********************APPENDIX TABLES*****************
	********************************************************
	
		
	// APPENDIX TABLE 2 & 8: Event Study Estimates
	local es1 "$es1_TDcont $es1_MCV $es1_HPV"
	
	estimates clear
	
	foreach var of global LHS1{
	
	eststo: reg `var' `es1' Meas_newlybind Varic_newlybind HepB_newlybind HepA_newlybind $Vacc_controls $individ_controls $styr i.fips i.age i.year12 [aw=provwt], vce(cluster fips)
	estadd ysumm
	estadd local linear ""
	estadd local yr ""
	
	eststo: reg `var' `es1' Meas_newlybind Varic_newlybind HepB_newlybind HepA_newlybind $Vacc_controls $individ_controls $styr $linear i.fips i.age i.year12 [aw=provwt], vce(cluster fips)
	estadd ysumm
	estadd local linear "X"
	estadd local yr ""

		}

			//HPV ES, with 1 years prior omitted (males and females, year13>=2009)
	foreach var of global hpvLHS_2{
	eststo: reg `var' `es1'   Meas_newlybind Varic_newlybind HepB_newlybind HepA_newlybind $Vacc_controls $individ_controls $styr i.fips i.age i.year12 [aw=provwt] if  hpv_tag==1, vce(cluster fips)
	estadd ysumm
	estadd local linear ""
	
	eststo: reg `var' `es1'  Meas_newlybind Varic_newlybind HepB_newlybind HepA_newlybind $Vacc_controls $individ_controls $styr $linear i.fips i.age i.year12 [aw=provwt] if  hpv_tag==1, vce(cluster fips)
	estadd ysumm
	estadd local linear "X"
		
	}
	
	/*APPENDIX TABLE 2: Tdap event studies*/
	esttab est1 est2 using "$output\vaccresults01152018.rtf", append wide keep($es1_TDcont) /*
	*/ se label star(* 0.10 ** 0.05 *** 0.01) stats(N r2 ymean linear, label("N" "R-Squared" "Mean of Dependent" "linear trend")) title(Effects of mandates on receipt of age-recommended vaccines) /*
	*/ note("All columns are weighted, have age, state and birth cohort fixed effects. SE are clustered at the state level.")
	
	/*APPENDIX TABLE 8: Spillover event studies*/
	esttab est3 est4 est5 est6 est7 est8 using "$output\vaccresults01152018.rtf", append wide keep($es1_TDcont) /*
	*/ se label star(* 0.10 ** 0.05 *** 0.01) stats(N r2 ymean linear, label("N" "R-Squared" "Mean of Dependent" "linear trend")) title(Effects of mandates on receipt of age-recommended vaccines) /*
	*/ note("All columns are weighted, have age, state and birth cohort fixed effects. SE are clustered at the state level.")
	
	
	/*APPENDIX TABLE 9: outcome variables are receipt of BOTH Tdap AND --- */
	 global TDAPy_1 "TDAPyMEN" //TDAPyflu"
	 global TDAPy_2 "TDAPyHPV1 TDAPyHPV3 TDAPyMENyHPV1 TDAPyMENyHPV3"
	
	estimates clear
	foreach var of global TDAPy_1{

	eststo: reg `var' $VaccMandates $Vacc_controls  $individ_controls $styr i.age i.fips i.year12  $linear [aw=provwt], vce(cluster fips)
	estadd ysumm
	estadd local linear "X"
	}
	
	foreach var of global TDAPy_2{
	
	eststo: reg `var' $VaccMandates $Vacc_controls    $individ_controls $styr i.age i.fips i.year12  $linear [aw=provwt] if year13>=2009, vce(cluster fips)
	estadd ysumm
	estadd local linear "X"
	}
	
	esttab est* using "$output\vaccresults01152018.rtf", append keep(TDcont_mandate) /*
	*/ se label star(* 0.10 ** 0.05 *** 0.01) stats(N r2 ymean linear, label("N" "R-Squared" "Mean of Dependent" "linear trend")) title(Robustness: effect of mandates on receipt of both Tdap and other vacc.) /*
	*/ note("All columns are weighted, have age, state and birth cohort fixed effects. SE are clustered at the state level.")
	

	/*APPENDIX TABLE 11: Interaction Effect with ACIP Recommendations*/ 
	
	estimates clear
	eststo: reg P_U13MEN TDcontmXacipMCV $VaccMandates $Vacc_controls  $individ_controls $styr i.age i.fips i.year12  $linear [aw=provwt], vce(cluster fips)
	estadd ysumm
	estadd local linear "X"
	
	eststo: reg hpv1_13 TDcontmXacipHPV $VaccMandates $Vacc_controls  $individ_controls $styr i.age i.fips i.year12  $linear [aw=provwt] if hpv_tag==1, vce(cluster fips)
	estadd ysumm
	estadd local linear "X"
	
	eststo: reg hpv3_13 TDcontmXacipHPV $VaccMandates $Vacc_controls  $individ_controls $styr i.age i.fips i.year12  $linear [aw=provwt] if hpv_tag==1, vce(cluster fips)
	estadd ysumm
	estadd local linear "X"
	
	eststo: reg flu_10_13 TDcontmXacipFlu $VaccMandates $Vacc_controls  $individ_controls $styr i.age i.fips i.year12  $linear [aw=provwt], vce(cluster fips)
	estadd ysumm
	estadd local linear "X"
	
		
	esttab est* using "$output\vaccresults01152018.rtf", append keep(TDcont_mandate TDcontmXacipMCV TDcontmXacipHPV TDcontmXacipFlu) /*
	*/ se label star(* 0.10 ** 0.05 *** 0.01) stats(N r2 ymean linear, label("N" "R-Squared" "Mean of Dependent" "linear trend")) title(Robustness: effects of acip recs on spillovers) /*
	*/ note("All columns are weighted, have age, state and birth cohort fixed effects. SE are clustered at the state level.")
	
		/*APPENDIX TABLE 12: Main Vaccination results for the samples in Table 5*/
	
	//For Table 5, there are 3 separate samples used:
		// 1) female==1 & year13>=2007  & age==13 (columns 1-4)
		// 2) hpv_tag==1 & age==13 (columns 5 & 6)
		// 3) age==13 (columns (7 & 8) 
		
	local t5_samp1 "female==1 & year13>=2007  & age==13 & hpv_heard!=."
	local t5_samp2 "female==1 & year13>=2007  & age==13 & hpv_vaccknow!=."
	local t5_samp3 "hpv_tag==1 & age==13 & hpv_rec!=."
	local t5_samp4 "age==13 & ckup_11_12!=."
	
	forvalues i=1/4{
	estimates clear
	foreach lhs of varlist P_U13TDAP P_U13MEN hpv1_13 hpv3_13{
	quietly{
	eststo: reg `lhs' $VaccMandates $Vacc_controls  $individ_controls $styr i.age i.fips i.year12 [aw=rddwt] if `t5_samp`i'', vce(cluster fips)
	estadd ysumm
	estadd local linear ""
	estadd local samp "`t5_samp`i''"
	
	
	eststo: reg `lhs' $VaccMandates $Vacc_controls  $individ_controls $styr i.age i.fips i.year12  $linear [aw=rddwt] if `t5_samp`i'', vce(cluster fips)
	estadd ysumm
	estadd local linear "X"
	estadd local samp "`t5_samp`i''"
	}
	tab year12 if e(sample)==1  [aw=rddwt]
	sum `lhs' if e(sample)==1 & year12==2007 [aw=rddwt]
	local samp`i'_`lhs' r(mean)

	}
	esttab est* using "$output\vaccresults01152018.rtf", append keep(TDcont_mandate ) /*
	*/ se label star(* 0.10 ** 0.05 *** 0.01) stats(N r2 ymean linear samp, label("N" "R-Squared" "Mean of Dependent" "linear trend" "Sample restriction:")) title(Robustness: Main results using Table 5 samples) /*
	*/ note("All columns are weighted, have age, state and birth cohort fixed effects. SE are clustered at the state level. Base year means: `lhs' = `samp`i'_`lhs''")
	
	 }
	*********************************************
	**********  EXTRA TABLES// ROBUSTNESS *******************
	******************************************
	

	
	//EXTRA TABLE: OMITTING INDIVIDUAL CONTROLS
	
	estimates clear
	
	eststo: reg P_U13TDAP $VaccMandates $Vacc_controls   $styr  i.fips i.year12  $linear [aw=provwt], vce(cluster fips)
	estadd ysumm
	estadd local linear "X"
	
	
	eststo: reg P_U13MEN $VaccMandates $Vacc_controls  $styr  i.fips i.year12  $linear [aw=provwt], vce(cluster fips)
	estadd ysumm
	estadd local linear "X"
	
	
	eststo: reg hpv1_13  $VaccMandates $Vacc_controls     $styr  i.fips i.year12  $linear [aw=provwt] if hpv_tag==1, vce(cluster fips)
	estadd ysumm
	estadd local linear "X"
	
	eststo: reg hpv3_13  $VaccMandates $Vacc_controls     $styr  i.fips i.year12  $linear [aw=provwt] if  hpv_tag==1, vce(cluster fips)
	estadd ysumm
	estadd local linear "X"
		
	esttab est* using "$output\vaccresults01152018.rtf", append keep(TDcont_mandate) /*
	*/ se label star(* 0.10 ** 0.05 *** 0.01) stats(N r2 ymean linear, label("N" "R-Squared" "Mean of Dependent" "linear trend")) title(Robustness: Omitting individual controls) /*
	*/ note("All columns are weighted, have state and birth cohort fixed effects. SE are clustered at the state level.")
	
	
	//EXTRA TABLE: OMITTING STATE CONTROLS
	
	estimates clear
	
	eststo: reg P_U13TDAP TDcont_mandate $individ_controls i.age i.fips i.year12  $linear [aw=provwt], vce(cluster fips)
	estadd ysumm
	estadd local linear "X"
	
	eststo: reg P_U13MEN TDcont_mandate $individ_controls i.age i.fips i.year12  $linear [aw=provwt], vce(cluster fips)
	estadd ysumm
	estadd local linear "X"
	
	eststo: reg hpv1_13  TDcont_mandate $individ_controls i.age i.fips i.year12  $linear [aw=provwt] if hpv_tag==1, vce(cluster fips)
	estadd ysumm
	estadd local linear "X"
		
	
	eststo: reg hpv3_13  TDcont_mandate $individ_controls i.age i.fips i.year12  $linear [aw=provwt] if  hpv_tag==1, vce(cluster fips)
	estadd ysumm
	estadd local linear "X"
	
		
	esttab est* using "$output\vaccresults01152018.rtf", append keep(TDcont_mandate) /*
	*/ se label star(* 0.10 ** 0.05 *** 0.01) stats(N r2 ymean linear, label("N" "R-Squared" "Mean of Dependent" "linear trend")) title(Robustness: Omitting state controls) /*
	*/ note("All columns are weighted, have age, state and birth cohort fixed effects. SE are clustered at the state level.")
	

	
//EXTRA TABLE: adding controls for SECTION 317 funds, VFC, and pharmacist vaccination authority
	local cont1 "s317_total"
	local cont2 "vfc_underins vfc_underins_select vfc_uni vfc_unisel vfc_other" //vfc_only is omitted category
	local cont3 "gaOrx"
	
	gen samp1_tag = 0
		replace samp1_tag=1 if s317_total!=.
	gen samp2_tag = 0
		replace samp2_tag=1 if vfc_only!=.
	gen samp3_tag = 0
		replace samp3_tag=1 if pharmlaw_miss==0
global LHS_robust1 "P_U13TDAP P_U13MEN"
global HPV_robust1 "hpv1_13 hpv3_13"
	
forvalues i=1/3{
estimates clear
foreach var of global LHS_robust1{

	/*
	*Baseline estimate with restricted sample
	eststo: reg `var' $VaccMandates $Vacc_controls  $individ_controls $styr i.age i.fips i.year12  $linear [aw=provwt]  if samp`i'_tag==1, vce(cluster fips)
	estadd ysumm
	estadd local linear "X"
	*/

	eststo: reg `var' `cont`i'' $VaccMandates $Vacc_controls  $individ_controls $styr i.age i.fips i.year12  $linear [aw=provwt]  if samp`i'_tag==1, vce(cluster fips)
	estadd ysumm
	estadd local linear "X"
	
		
}
	

foreach var of global HPV_robust1{

/*
	*Baseline estimate with restricted sample
	eststo: reg `var' $VaccMandates $Vacc_controls    $individ_controls $styr i.age i.fips i.year12  $linear if hpv_tag==1 & samp`i'_tag==1 [aw=provwt], vce(cluster fips)
	estadd ysumm
	estadd local linear "X"
		*/
	eststo: reg `var' `cont`i'' $VaccMandates $Vacc_controls    $individ_controls $styr i.age i.fips i.year12  $linear  if hpv_tag==1 & samp`i'_tag==1 [aw=provwt], vce(cluster fips)
	estadd ysumm
	estadd local linear "X"
	
	
}
esttab est* using "$output\vaccresults01152018.rtf", append keep(TDcont_mandate) /*
	*/ se label star(* 0.10 ** 0.05 *** 0.01) stats(N r2 ymean linear, label("N" "R-Squared" "Mean of Dependent" "linear trend")) title(Robustness: Including `cont`i'' as controls) /*
	*/ note("All columns are weighted, have age, state and birth cohort fixed effects. SE are clustered at the state level.")
}
	
	//EXTRA TABLE: controlling for pharmacist scope of practice and including interaction
		estimates clear
		
	foreach var of global LHS1{

	eststo: reg `var' $VaccMandates gaOrx garxXmandate $Vacc_controls  $individ_controls $styr i.age i.fips i.year12 if pharmlaw_miss==0 [aw=provwt], vce(cluster fips)
	estadd ysumm
	estadd local linear ""
	estadd local quad ""
	
	eststo: reg `var' $VaccMandates gaOrx garxXmandate $Vacc_controls  $individ_controls $styr i.age i.fips i.year12  $linear if pharmlaw_miss==0 [aw=provwt], vce(cluster fips)
	estadd ysumm
	estadd local linear "X"
	estadd local quad ""
	
	
	}
	//main hpv result
	
	foreach var of global hpvLHS_2{
		
		eststo: reg `var'  $VaccMandates  gaOrx garxXmandate $Vacc_controls  $individ_controls $styr  i.age i.fips i.year12 [aw=provwt] if  hpv_tag==1 & pharmlaw_miss==0, vce(cluster fips)
	estadd ysumm
	estadd local linear ""
	estadd local quad ""

	eststo: reg `var'  $VaccMandates gaOrx garxXmandate $Vacc_controls $individ_controls $styr  i.age i.fips i.year12  $linear [aw=provwt] if hpv_tag==1 & pharmlaw_miss==0, vce(cluster fips)
	estadd ysumm
	estadd local linear "X"
	estadd local quad ""
	
	
	}
	esttab est* using "$output\vaccresults01152018.rtf", append keep(TDcont_mandate  ga* ) /*
	*/ se label star(* 0.10 ** 0.05 *** 0.01) stats(N r2 ymean linear quad, label("N" "R-Squared" "Mean of Dependent" "linear trend" "quadratic trend")) title(Extra Table: Interaction Effects with Pharmacist Scope of Practice) /*
	*/ note("All columns are weighted, have age, state and birth cohort fixed effects. SE are clustered at the state level.")

	//EXTRA TABLE: dropping kids who no longer live in their state of birth
	estimates clear
	
	eststo: reg P_U13TDAP $VaccMandates $Vacc_controls  $individ_controls $styr i.age i.fips i.year12  $linear [aw=provwt] if MOBIL_I==2, vce(cluster fips)
	estadd ysumm
	estadd local linear "X"
	

	eststo: reg P_U13MEN $VaccMandates $Vacc_controls  $individ_controls $styr i.age i.fips i.year12  $linear [aw=provwt] if MOBIL_I==2, vce(cluster fips)
	estadd ysumm
	estadd local linear "X"
	
	eststo: reg hpv1_13  $VaccMandates $Vacc_controls    $individ_controls $styr i.age i.fips i.year12  $linear [aw=provwt] if hpv_tag==1 & MOBIL_I==2, vce(cluster fips)
	estadd ysumm
	estadd local linear "X"
		

	eststo: reg hpv3_13  $VaccMandates $Vacc_controls    $individ_controls $styr i.age i.fips i.year12  $linear [aw=provwt] if  hpv_tag==1 & MOBIL_I==2, vce(cluster fips)
	estadd ysumm
	estadd local linear "X"
	
	esttab est* using "$output\vaccresults01152018.rtf", append keep(TDcont_mandate) /*
	*/ se label star(* 0.10 ** 0.05 *** 0.01) stats(N r2 ymean linear, label("N" "R-Squared" "Mean of Dependent" "linear trend")) title(Robustness:Restricted to sample that resides in state of birth (2009-2014)) /*
	*/ note("All columns are weighted, have age, state and birth cohort fixed effects. SE are clustered at the state level.")
	
	
		//EXTRA TABLE: MAIN RESULTS, NO WEIGHTS
	estimates clear
	
	eststo: reg P_U13TDAP $VaccMandates $Vacc_controls  $individ_controls $styr i.age i.fips i.year12  $linear, vce(cluster fips)
	estadd ysumm
	estadd local linear "X"
	
	
	eststo: reg P_U13MEN $VaccMandates $Vacc_controls  $individ_controls $styr i.age i.fips i.year12  $linear, vce(cluster fips)
	estadd ysumm
	estadd local linear "X"
	
		

	eststo: reg hpv1_13  $VaccMandates $Vacc_controls    $individ_controls $styr i.age i.fips i.year12  $linear if hpv_tag==1, vce(cluster fips)
	estadd ysumm
	estadd local linear "X"
		

	eststo: reg hpv3_13  $VaccMandates $Vacc_controls    $individ_controls $styr i.age i.fips i.year12  $linear  if  hpv_tag==1, vce(cluster fips)
	estadd ysumm
	estadd local linear "X"
	
		esttab est* using "$output\vaccresults01152018.rtf", append keep(TDcont_mandate) /*
	*/ se label star(* 0.10 ** 0.05 *** 0.01) stats(N r2 ymean linear, label("N" "R-Squared" "Mean of Dependent" "linear trend")) title(Robustness:No weights) /*
	*/ note("All columns exclude weights, have age, state and birth cohort fixed effects. SE are clustered at the state level.")
	

	
	//EXTRA TABLE: verifying not sensitive to 2011 weighting decision
	replace provwt= provwt_ll if year==2011
	estimates clear
	foreach var of global LHS1{

	
	eststo: reg `var' $VaccMandates $Vacc_controls  $individ_controls $styr i.age i.fips i.year12  $linear [aw=provwt], vce(cluster fips)
	estadd ysumm
	estadd local linear "X"
	estadd local quad ""
	}

	//main hpv result
	foreach var of global hpvLHS{
	

	eststo: reg `var'  $VaccMandates $Vacc_controls $individ_controls $styr  i.age i.fips i.year12  $linear [aw=provwt] if hpv_tag==1, vce(cluster fips)
	estadd ysumm
	estadd local linear "X"
	estadd local quad ""
	
	}
		
	esttab est* using "$output\vaccresults01152018.rtf", append keep(TDcont_mandate) /*
	*/ se label star(* 0.10 ** 0.05 *** 0.01) stats(N r2 ymean linear quad, label("N" "R-Squared" "Mean of Dependent" "linear trend" "quadratic trend")) title(Robustness: USING LL WEIGHTS IN 2011) /*
	*/ note("All columns are weighted, have age, state and birth cohort fixed effects. SE are clustered at the state level.")
	

	replace provwt= provwt_d if year==2011
	
	
		/*EXTRA Table: Heterogeneity by Facility Type*/
		
	//facility type: all public
	estimates clear
	foreach var of global hetero_LHS{
	eststo: reg `var' $VaccMandates $Vacc_controls  $individ_controls $styr i.age i.fips i.year12 $linear [aw=provwt] if facility==1 , vce(cluster fips)
	estadd ysumm
	estadd local yr "`lab`i''"
	}
	foreach var of global hpvLHS_2{
	eststo: reg `var' $VaccMandates $Vacc_controls  $individ_controls $styr i.age i.fips i.year12 $linear [aw=provwt] if facility==1 & hpv_tag==1 , vce(cluster fips)
	estadd ysumm
	estadd local yr "`lab`i''"
	}
	esttab est* using "$output\vaccresults01152018.rtf", append keep(TDcont_mandate) /*
	*/ se label star(* 0.10 ** 0.05 *** 0.01) stats(yr N r2 ymean, label("Sample" "N" "R-Squared" "Mean of Dependent")) title(Effects of mandates, heterogeneity analysis: public facilities) /*
	*/ note("All columns are weighted, have age, state and birth cohort fixed effects. SE are clustered at the state level.")
	
	
	//facility type: all private
	
	estimates clear
	foreach var of global hetero_LHS{
	eststo: reg `var' $VaccMandates $Vacc_controls  $individ_controls $styr i.age i.fips i.year12 $linear [aw=provwt] if facility==3 , vce(cluster fips)
	estadd ysumm
	estadd local yr "`lab`i''"
	}
	foreach var of global hpvLHS_2{
	eststo: reg `var' $VaccMandates $Vacc_controls  $individ_controls $styr i.age i.fips i.year12 $linear [aw=provwt] if facility==3  & hpv_tag==1 , vce(cluster fips)
	estadd ysumm
	estadd local yr "`lab`i''"
	}
	esttab est* using "$output\vaccresults01152018.rtf", append keep(TDcont_mandate) /*
	*/ se label star(* 0.10 ** 0.05 *** 0.01) stats(yr N r2 ymean, label("Sample" "N" "R-Squared" "Mean of Dependent")) title(Effects of mandates, heterogeneity analysis: private facilities) /*
	*/ note("All columns are weighted, have age, state and birth cohort fixed effects. SE are clustered at the state level.")
	
	
	
	//facility type: mixed
	estimates clear
	foreach var of global hetero_LHS{
	eststo: reg `var' $VaccMandates $Vacc_controls  $individ_controls $styr i.age i.fips i.year12 $linear [aw=provwt] if facility==5 , vce(cluster fips)
	estadd ysumm
	estadd local yr "`lab`i''"
	}
	foreach var of global hpvLHS_2{
	eststo: reg `var' $VaccMandates $Vacc_controls  $individ_controls $styr i.age i.fips i.year12 $linear [aw=provwt] if facility==5 & hpv_tag==1 , vce(cluster fips)
	estadd ysumm
	estadd local yr "`lab`i''"
	}
	esttab est* using "$output\vaccresults01152018.rtf", append keep(TDcont_mandate) /*
	*/ se label star(* 0.10 ** 0.05 *** 0.01) stats(yr N r2 ymean, label("Sample" "N" "R-Squared" "Mean of Dependent")) title(Effects of mandates, heterogeneity analysis: mixed facilities) /*
	*/ note("All columns are weighted, have age, state and birth cohort fixed effects. SE are clustered at the state level.")
		
/* EXTRA TABLE: Heterogeneity by health insurance type */

		gen postACA = year12>=2011 //ACA mandated coverage of imm eff. September 23, 2010
	gen mandateXpostACA = TDcont_mandate * postACA
	gen mandateXimminsure = TDcont_mandate * imminsure_12yo
	
	local ins1 "ins_private"
		local lbl1 "private"
	local ins2 "ins_public"
		local lbl2 "public"

	
forvalues i=1/2{
	estimates clear
	foreach var of global hetero_LHS{
		
	eststo: reg `var' $VaccMandates $Vacc_controls  $individ_controls $styr i.age i.fips i.year12 $linear [aw=provwt] if age==13 & `ins`i''==1 , vce(cluster fips)
	estadd ysumm
	estadd local yr "`lbl`i'', age 13"
	
	}
		
	foreach var of global hpvLHS_2{
	
	eststo: reg `var' $VaccMandates $Vacc_controls  $individ_controls $styr i.age i.fips i.year12 $linear [aw=provwt] if age==13 & `ins`i''==1 & hpv_tag==1 , vce(cluster fips)
	estadd ysumm
	estadd local yr "`lbl`i'', age 13"
	
}
	esttab est* using "$output\vaccresults01152018.rtf", append keep(TDcont_mandate) /*
	*/ se label star(* 0.10 ** 0.05 *** 0.01) stats(yr N r2 ymean, label("Sample" "N" "R-Squared" "Mean of Dependent")) title(Effects of mandates, heterogeneity analysis: `lbl`i'' insurance) /*
	*/ note("All columns are weighted, have age, state and birth cohort fixed effects. SE are clustered at the state level.")
	
	}
	

	/*EXTRA TABLE: Testing for heterogeneity in mandate effect based on presence of immunization insurance coverage mandates*/ 
	estimates clear
		forvalues i=1/2{
		
	eststo: reg P_U13TDAP $VaccMandates $Vacc_controls  $individ_controls $styr i.age i.fips i.year12 $linear [aw=provwt] if age==13 & `ins`i''==1 , vce(cluster fips)
	estadd ysumm
	estadd local yr "`lbl`i'', age 13"
	
	eststo: reg P_U13TDAP $VaccMandates mandateXimminsure $Vacc_controls  $individ_controls $styr i.age i.fips i.year12 $linear [aw=provwt] if age==13 & `ins`i''==1 , vce(cluster fips)
	estadd ysumm
	estadd local yr "`lbl`i'', age 13"
	
	eststo: reg P_U13TDAP $VaccMandates mandateXpostACA $Vacc_controls  $individ_controls $styr i.age i.fips i.year12 $linear [aw=provwt] if age==13 & `ins`i''==1 , vce(cluster fips)
	estadd ysumm
	estadd local yr "`lbl`i'', age 13"
	
	}
	esttab est* using "$output\vaccresults01152018.rtf", append keep(TDcont_mandate mandateXimminsure mandateXpostACA imminsure_12yo) /*
	*/ se label star(* 0.10 ** 0.05 *** 0.01) stats(yr N r2 ymean, label("Sample" "N" "R-Squared" "Mean of Dependent")) title(Effects of mandates, heterogeneity analysis: `lbl`i'' insurance) /*
	*/ note("All columns are weighted, have age, state and birth cohort fixed effects. SE are clustered at the state level.")
	
	
	